/*-------------------------------------------------------------------------
 |                                                                         
 |                    SAS SETUP FILE FOR ICPSR 03088
 |           ALCOHOL AND DRUG SERVICES STUDY (ADSS), 1996-1999:
 |                            [UNITED STATES]
 |            (DATASET 0005: PHASE II EARLY DROPOUT ABSTRACT)
 |
 |
 | SAS setup sections are provided for the ASCII version of this data
 | collection.  These sections are listed below:
 |
 | PROC FORMAT:  creates user-defined formats for the variables. Formats
 | replace original value codes with value code descriptions. Only
 | variables with user-defined formats are included in this section.
 |
 | DATA:  begins a SAS data step and names an output SAS data set.
 |
 | INFILE:  identifies the input file to be read with the input statement.
 | Users must replace the "data-filename" with a filename specifying the
 | directory on the user's computer system in which the downloaded and
 | unzipped data file is physically located (e.g.,
 | "c:\temp\03088-0005-data.txt").
 |
 | INPUT:  assigns the name, type, decimal specification (if any), and
 | specifies the beginning and ending column locations for each variable
 | in the data file.
 |
 | LABEL:  assigns descriptive labels to all variables. Variable labels
 | and variable names may be identical for some variables.
 |
 | MISSING VALUE RECODES:  sets user-defined numeric missing values to
 | missing as interpreted by the SAS system. Only variables with
 | user-defined missing values are included in this section.
 |
 | If any variables have more than one missing value, they are assigned
 | to the standard missing value of a single period (.) in the statement
 | below. To maintain the original meaning of missing codes, users may want
 | to take advantage of the SAS missing values (the letters A-Z or an
 | underscore preceded by a period).
 |
 | An example of a standard missing value recode:
 |
 |   IF (RELATION = 98 OR RELATION = 99) THEN RELATION = .; 
 |
 | The same example using special missing value recodes:
 |
 |    IF RELATION = 98 THEN RELATION = .A;
 |    IF RELATION = 99 THEN RELATION = .B;
 |
 | FORMAT:  associates the formats created by the PROC FORMAT step with
 | the variables named in the INPUT statement.
 |
 | NOTE:  Users should modify this setup file to suit their specific needs.
 | Sections for PROC FORMAT, FORMAT, and MISSING VALUE RECODES have been
 | commented out (i.e., '/*'). To include these sections in the final SAS
 | setup, users should remove the SAS comment indicators from the desired
 | section(s).
 |
 |------------------------------------------------------------------------*/

* SAS PROC FORMAT;

/*
PROC FORMAT;
  VALUE cltype    1='(1) NONMETHADONE DISCHARGE' 2='(2) METHADONE DISCHARGE'
                  3='(3) IN-TREATMENT METHADONE' ;
  VALUE comin     -7='(-7) NOT ASCERTAINED' -5='(-5) MISSING' ;
  VALUE a6ffffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) NON-HOSPITAL RESIDENTIAL'
                  2='(2) OUTPATIENT' 3='(3) OTHER (IF COMBINATIONS, SPECIFY TYPE AND'
                  4='(4) RESIDENTIAL AND OUTPATIENT' 5='(5) SPLIT' ;
  VALUE a6a1ffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 0='(0) NO' 1='(1) YES' ;
  VALUE a6a2ffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 0='(0) NO' 1='(1) YES' ;
  VALUE a6a3ffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 0='(0) NO' 1='(1) YES' ;
  VALUE a7ffffff  -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO' 1='(1) YES' ;
  VALUE a9ffffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) OTHER TREATMENT REFERRED'
                  2='(2) CRIMINAL JUSTICE SYSTEM' 3='(3) SELF-REFERRED/VOLUNTARY'
                  4='(4) FAMILY' 5='(5) FRIEND REFERRED' 6='(6) EMPLOYER'
                  7='(7) HEALTH CARE OR MENTAL HEALTH PROVIDES'
                  8='(8) WELFARE OFFICE OR OTHER SOCIAL SERVICE A'
                  9='(9) YELLOW PAGES'
                  10='(10) MOTOR VEHICLES ADMIN, INTOXICATED DRIVER'
                  11='(11) PRIVATE REFERRAL' 12='(12) SCHOOL' 13='(13) INSURANCE COMPANY'
                  14='(14) TV AD' 88='(88) OTHER' ;
  VALUE a10fffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED/NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) NO PAYMENT' 2='(2) CLIENT SELF PAYMENT'
                  3='(3) PRIVATE HEALTH INSURANCE, FEE-FOR-SERVIC'
                  4='(4) PRIVATE HEALTH INSURANCE, HMO/PPO/MANAGE'
                  5='(5) CRIMINAL JUSTICE SYSTEM' 6='(6) MEDICAID' 7='(7) MEDICARE'
                  8='(8) OTHER PUBLIC FUNDING'
                  9='(9) EMPLOYEE ASSISTANCE PROGRAM/PLAN'
                  10='(10) INSURANCE, FEE -FOR-SERVICE OR MANAGED C'
                  11='(11) MEDICAL COUPON' 12='(12) RESEARCH GRANT PAYMENT' 13='(13) HAP'
                  14='(14) WORKERS COMPENSATION' 15='(15) CONTRACT/SLIDING FEE'
                  16='(16) 50/50 CLIENT, INSURANCE' 17='(17) SCHOOL PROGRAM'
                  66='(66) NOT PERMITTED TO ABSTRACT' 88='(88) OTHER' ;
  VALUE a11fffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 0='(0) NO' 1='(1) YES' ;
  VALUE a14fffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) MALE' 2='(2) FEMALE' ;
  VALUE a15fffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) WHITE' 2='(2) BLACK'
                  3='(3) AMERICAN INDIAN OR ALASKAN NATIVE'
                  4='(4) ASIAN OR PACIFIC ISLANDER'
                  5='(5) OTHER NON-WHITE/MIXED RACE' 8='(8) OTHER, NOT FURTHER CODED' ;
  VALUE a16fffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) HISPANIC' 2='(2) NOT OF HISPANIC ORIGIN' ;
  VALUE a17fffff  -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NEVER MARRIED'
                  1='(1) MARRIED/COMMON LAW' 2='(2) WIDOWED' 3='(3) SEPARATED/DIVORCED'
                  4='(4) SINGLE' 8='(8) OTHER NOT FURTHER CODED' ;
  VALUE a18fffff  -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO' 1='(1) YES' ;
  VALUE a19fffff  -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO' 1='(1) YES' ;
  VALUE a20fffff  -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED/NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  0='(0) NO STABLE ARRANGEMENT (INCLUDE HOMELESS,'
                  1='(1) WITH SPOUSE/PARTNER' 2='(2) WITH PARENT(S)'
                  3='(3) WITH OTHER FAMILY' 4='(4) WITH FRIENDS' 5='(5) ALONE'
                  6='(6) WITH NO OTHER ADULT(S)/CHILDREN ONLY'
                  7='(7) CORRECTIONAL FACILITY' 8='(8) OTHER INSTITUTION' ;
  VALUE a21fffff  -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 1='(1) LESS THAN 8 YEARS'
                  2='(2) 8 - 11 YEARS'
                  3='(3) LESS THAN H.S. GRADUATE, NOT OTHERWISE S'
                  4='(4) H.S. GRADUATE/GED' 5='(5) SOME COLLEGE' 6='(6) COLLEGE GRADUATE'
                  7='(7) POSTGRADUATE' 8='(8) OTHER, NOT FURTHER CODED' ;
  VALUE a22fffff  -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO' 1='(1) YES' ;
  VALUE a23fffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) FULL-TIME (35HRS/WK OR MORE)'
                  2='(2) PART-TIME (LESS THAN 35 HRS/WK)'
                  3='(3) EMPLOYED, NOT OTHERWISE SPECIFIED'
                  4='(4) KEEPING HOUSE, NOT OTHERWISE EMPLOYED' 5='(5) RETIRED'
                  6='(6) DISABLED' 7='(7) INMATE' 8='(8) UNEMPLOYED' 9='(9) LAID OFF'
                  10='(10) STUDENT' 11='(11) ON PROBATION FROM JOB, SUSPENDED'
                  12='(12) ON LEAVE, MEDICAL LEAVE, ON WORKERS COMP'
                  13='(13) IRREGULAR' 14='(14) NACO' 88='(88) OTHER, NOT FURTHER CODED' ;
  VALUE a24fffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) CLERICAL WORKER' 2='(2) SALES WORKER'
                  3='(3) SERVICE WORKER' 4='(4) PRIVATE HH WORKER'
                  5='(5) SKILLED WORKER OR CRAFTSMAN' 6='(6) LABORER'
                  7='(7) OPERATOR OR MACHINE OPERATOR'
                  8='(8) TRANSPORTATION EQUIPMENT OPERATOR' 9='(9) FARM LABORER)'
                  10='(10) FARMER OR FARM MANAGER' 11='(11) MANAGER/ADMINISTRATOR'
                  12='(12) LAY COUNSELOR' 13='(13) PROFESSIONAL/TECHNICAL' 14='(14) STUDENT'
                  15='(15) DRUG DEALER, GAMBLER, ETC, OTHER ILLEGAL'
                  86='(86) EMPLOYER GIVEN/NO OCCUPATION GIVEN'
                  88='(88) OCCUPATION SPECIFIED, MISCELLANEOUS CODE' ;
  VALUE a25fffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 0='(0) NONE' 1='(1) YES'
                  6='(6) NOT PERMITTED TO ABSTRACT' ;
  VALUE a26fffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 0='(0) NONE' 1='(1) YES'
                  6='(6) NOT PERMITTED TO ABSTRACT' ;
  VALUE a27fffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 0='(0) NONE' 1='(1) YES'
                  6='(6) NOT PERMITTED TO ABSTRACT' ;
  VALUE a28fffff  -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NONE' 1='(1) YES'
                  6='(6) NOT PERMITTED TO ABSTRACT' ;
  VALUE a29fffff  -7='(-7) NOT ASCERTAINED' ;
  VALUE a30a      -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NONE' 1='(1) YES'
                  6='(6) NOT PERMITTED TO ABSTRACT' ;
  VALUE a30b      -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NONE' 1='(1) YES'
                  6='(6) NOT PERMITTED TO ABSTRACT' ;
  VALUE a30c      -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NONE' 1='(1) YES'
                  6='(6) NOT PERMITTED TO ABSTRACT' ;
  VALUE a30d      -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NONE' 1='(1) YES'
                  6='(6) NOT PERMITTED TO ABSTRACT' ;
  VALUE a30e      -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NONE' 1='(1) YES'
                  6='(6) NOT PERMITTED TO ABSTRACT' ;
  VALUE a30f      -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NONE' 1='(1) YES'
                  6='(6) NOT PERMITTED TO ABSTRACT' ;
  VALUE a30g      -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NONE' 1='(1) YES'
                  6='(6) NOT PERMITTED TO ABSTRACT' ;
  VALUE a30h      -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NONE' 1='(1) YES'
                  6='(6) NOT PERMITTED TO ABSTRACT' ;
  VALUE a30i      -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NONE' 1='(1) YES'
                  6='(6) NOT PERMITTED TO ABSTRACT' ;
  VALUE a30j      -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NONE' 1='(1) YES'
                  6='(6) NOT PERMITTED TO ABSTRACT' ;
  VALUE a31fffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 0='(0) NONE' 1='(1) YES' ;
  VALUE a32fffff  -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NONE'
                  1='(1) YES, ANTIDEPRESSANT' 2='(2) YES, ANTIPSYCHOTIC'
                  3='(3) YES, BOTH' ;
  VALUE a33a      -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NONE' 1='(1) YES' ;
  VALUE a33b      -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NONE' 1='(1) YES' ;
  VALUE a33c      -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NONE' 1='(1) YES' ;
  VALUE a33d      -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NONE' 1='(1) YES' ;
  VALUE a33e      -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NONE' 1='(1) YES' ;
  VALUE a33f      -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NONE' 1='(1) YES' ;
  VALUE a34fffff  -7='(-7) NOT ASCERTAINED' -4='(-4) DATA OUT OF RANGE' ;
  VALUE a35fffff  -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NONE' ;
  VALUE a36fffff  -9='(-9) NOT APPLICABLE, CLIENT IS MALE' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NOT PREGNANT'
                  1='(1) PREGNANT' ;
  VALUE a37fffff  -9='(-9) NOT APPLICABLE, CLIENT IS MALE, OR CLIEN' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NOT PREGNANT'
                  1='(1) PREGNANT' 2='(2) PREGNANT, BABY BORN DURING TREATMENT' ;
  VALUE a38fffff  -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  1='(1) DRUG ABUSE ONLY (EXCLUDING ALCOHOL)'
                  2='(2) ALCOHOL ABUSE ONLY' 3='(3) ALCOHOL AND DRUG ABUSE'
                  4='(4) SUSPECTED SUBSTANCE ABUSE PROBLEM, EVALU'
                  5='(5) FEAR OF RELAPSE' 6='(6) TO TREATMENT DIRECT FROM JAIL'
                  8='(8) OTHER, NOT FURTHER CODED' ;
  VALUE a39cn     -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  0='(0) NO DIAGNOSIS SPECIFIED' 1='(1) ONE DIAGNOSIS SPECIFIED'
                  2='(2) TWO DIAGNOSES SPECIFIED' 3='(3) THREE DIAGNOSES SPECIFIED'
                  4='(4) FOUR DIAGNOSES SPECIFIED' 5='(5) FIVE DIAGNOSES SPECIFIED'
                  6='(6) SIX DIAGNOSES SPECIFIED' 7='(7) SEVEN DIAGNOSES SPECIFIED'
                  8='(8) EIGHT DIAGNOSES SPECIFIED' ;
  VALUE a39a      -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -7='(-7) NOT ASCERTAINED'
                  -5='(-5) MISSING' 0='(0) NO DIAGNOSIS' 1='(1) ALCOHOL-INDUCED DISORDER'
                  2='(2) SUBSTANCE-INDUCED DISORDER' 3='(3) ALCOHOL INTOXICATION'
                  4='(4) ALCOHOL DEPENDENCE' 5='(5) OPIOID DEPENDENCE'
                  6='(6) COCAINE DEPENDENCE' 7='(7) CANNABIS DEPENDENCE'
                  8='(8) OTHER SUBSTANCE DEPENDENCE' 9='(9) ALCOHOL ABUSE'
                  10='(10) CANNABIS ABUSE' 11='(11) OTH SUBST ABUSE' 12='(12) OPIOID ABUSE'
                  13='(13) COCAINE ABUSE' 14='(14) ANXIETY DISORDERS'
                  15='(15) DEPRESSIVE DISORDERS'
                  16='(16) SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS'
                  17='(17) BIPOLAR DISORDERS'
                  18='(18) ATTENTION DEFICIT/DISRUPTIVE BEH. DISORD'
                  19='(19) OTHER MENTAL HEALTH CONDITION' 20='(20) OTHER CONDITION' ;
  VALUE a39b      -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -7='(-7) NOT ASCERTAINED'
                  -5='(-5) MISSING' 0='(0) NO DIAGNOSIS' 1='(1) ALCOHOL-INDUCED DISORDER'
                  2='(2) SUBSTANCE-INDUCED DISORDER' 3='(3) ALCOHOL INTOXICATION'
                  4='(4) ALCOHOL DEPENDENCE' 5='(5) OPIOID DEPENDENCE'
                  6='(6) COCAINE DEPENDENCE' 7='(7) CANNABIS DEPENDENCE'
                  8='(8) OTHER SUBSTANCE DEPENDENCE' 9='(9) ALCOHOL ABUSE'
                  10='(10) CANNABIS ABUSE' 11='(11) OTH SUBST ABUSE' 12='(12) OPIOID ABUSE'
                  13='(13) COCAINE ABUSE' 14='(14) ANXIETY DISORDERS'
                  15='(15) DEPRESSIVE DISORDERS'
                  16='(16) SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS'
                  17='(17) BIPOLAR DISORDERS'
                  18='(18) ATTENTION DEFICIT/DISRUPTIVE BEH. DISORD'
                  19='(19) OTHER MENTAL HEALTH CONDITION' 20='(20) OTHER CONDITION' ;
  VALUE a39c      -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -7='(-7) NOT ASCERTAINED'
                  -5='(-5) MISSING' 0='(0) NO DIAGNOSIS' 1='(1) ALCOHOL-INDUCED DISORDER'
                  2='(2) SUBSTANCE-INDUCED DISORDER' 3='(3) ALCOHOL INTOXICATION'
                  4='(4) ALCOHOL DEPENDENCE' 5='(5) OPIOID DEPENDENCE'
                  6='(6) COCAINE DEPENDENCE' 7='(7) CANNABIS DEPENDENCE'
                  8='(8) OTHER SUBSTANCE DEPENDENCE' 9='(9) ALCOHOL ABUSE'
                  10='(10) CANNABIS ABUSE' 11='(11) OTH SUBST ABUSE' 12='(12) OPIOID ABUSE'
                  13='(13) COCAINE ABUSE' 14='(14) ANXIETY DISORDERS'
                  15='(15) DEPRESSIVE DISORDERS'
                  16='(16) SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS'
                  17='(17) BIPOLAR DISORDERS'
                  18='(18) ATTENTION DEFICIT/DISRUPTIVE BEH. DISORD'
                  19='(19) OTHER MENTAL HEALTH CONDITION' 20='(20) OTHER CONDITION' ;
  VALUE a39d      -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -7='(-7) NOT ASCERTAINED'
                  -5='(-5) MISSING' 0='(0) NO DIAGNOSIS' 1='(1) ALCOHOL-INDUCED DISORDER'
                  2='(2) SUBSTANCE-INDUCED DISORDER' 3='(3) ALCOHOL INTOXICATION'
                  4='(4) ALCOHOL DEPENDENCE' 5='(5) OPIOID DEPENDENCE'
                  6='(6) COCAINE DEPENDENCE' 7='(7) CANNABIS DEPENDENCE'
                  8='(8) OTHER SUBSTANCE DEPENDENCE' 9='(9) ALCOHOL ABUSE'
                  10='(10) CANNABIS ABUSE' 11='(11) OTH SUBST ABUSE' 12='(12) OPIOID ABUSE'
                  13='(13) COCAINE ABUSE' 14='(14) ANXIETY DISORDERS'
                  15='(15) DEPRESSIVE DISORDERS'
                  16='(16) SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS'
                  17='(17) BIPOLAR DISORDERS'
                  18='(18) ATTENTION DEFICIT/DISRUPTIVE BEH. DISORD'
                  19='(19) OTHER MENTAL HEALTH CONDITION' 20='(20) OTHER CONDITION' ;
  VALUE a39e      -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -7='(-7) NOT ASCERTAINED'
                  -5='(-5) MISSING' 0='(0) NO DIAGNOSIS' 1='(1) ALCOHOL-INDUCED DISORDER'
                  2='(2) SUBSTANCE-INDUCED DISORDER' 3='(3) ALCOHOL INTOXICATION'
                  4='(4) ALCOHOL DEPENDENCE' 5='(5) OPIOID DEPENDENCE'
                  6='(6) COCAINE DEPENDENCE' 7='(7) CANNABIS DEPENDENCE'
                  8='(8) OTHER SUBSTANCE DEPENDENCE' 9='(9) ALCOHOL ABUSE'
                  10='(10) CANNABIS ABUSE' 11='(11) OTH SUBST ABUSE' 12='(12) OPIOID ABUSE'
                  13='(13) COCAINE ABUSE' 14='(14) ANXIETY DISORDERS'
                  15='(15) DEPRESSIVE DISORDERS'
                  16='(16) SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS'
                  17='(17) BIPOLAR DISORDERS'
                  18='(18) ATTENTION DEFICIT/DISRUPTIVE BEH. DISORD'
                  19='(19) OTHER MENTAL HEALTH CONDITION' 20='(20) OTHER CONDITION' ;
  VALUE a40eu     -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO/NEVER USED'
                  1='(1) YES' ;
  VALUE a40lu     -9='(-9) INAPPLICABLE, NEVER USED' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO' 1='(1) YES' ;
  VALUE a40age    -9='(-9) INAPPLICABLE, NEVER USED' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE a41eu     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 0='(0) NO/NEVER USED' 1='(1) YES' ;
  VALUE a41lu     -9='(-9) INAPPLICABLE, NEVER USED' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO' 1='(1) YES' ;
  VALUE a41age    -9='(-9) INAPPLICABLE, NEVER USED' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE a42eu     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 0='(0) NO/NEVER USED' 1='(1) YES' ;
  VALUE a42lu     -9='(-9) INAPPLICABLE, NEVER USED' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO' 1='(1) YES' ;
  VALUE a42age    -9='(-9) INAPPLICABLE, NEVER USED' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE a43eu     -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO/NEVER USED'
                  1='(1) YES' ;
  VALUE a43lu     -9='(-9) INAPPLICABLE, NEVER USED' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO' 1='(1) YES' ;
  VALUE a43age    -9='(-9) INAPPLICABLE, NEVER USED' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE a44eu     -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO/NEVER USED'
                  1='(1) YES' ;
  VALUE a44lu     -9='(-9) INAPPLICABLE, NEVER USED' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO' 1='(1) YES' ;
  VALUE a44age    -9='(-9) INAPPLICABLE, NEVER USED' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE a45eu     -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO/NEVER USED'
                  1='(1) YES' ;
  VALUE a45lu     -9='(-9) INAPPLICABLE, NEVER USED' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO' 1='(1) YES' ;
  VALUE a45age    -9='(-9) INAPPLICABLE, NEVER USED' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE a46eu     -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO/NEVER USED'
                  1='(1) YES' ;
  VALUE a46lu     -9='(-9) INAPPLICABLE, NEVER USED' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO' 1='(1) YES' ;
  VALUE a46age    -9='(-9) INAPPLICABLE, NEVER USED' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE a47eu     -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO/NEVER USED'
                  1='(1) YES' ;
  VALUE a47lu     -9='(-9) INAPPLICABLE, NEVER USED' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO' 1='(1) YES' ;
  VALUE a47age    -9='(-9) INAPPLICABLE, NEVER USED' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE a48eu     -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO/NEVER USED'
                  1='(1) YES' ;
  VALUE a48lu     -9='(-9) INAPPLICABLE, NEVER USED' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO' 1='(1) YES' ;
  VALUE a48age    -9='(-9) INAPPLICABLE, NEVER USED' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE a49eu     -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO/NEVER USED'
                  1='(1) YES' ;
  VALUE a49lu     -9='(-9) INAPPLICABLE, NEVER USED' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO' 1='(1) YES' ;
  VALUE a49age    -9='(-9) INAPPLICABLE, NEVER USED' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE a50eu     -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO/NEVER USED'
                  1='(1) YES' ;
  VALUE a50lu     -9='(-9) INAPPLICABLE, NEVER USED' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO' 1='(1) YES' ;
  VALUE a50age    -9='(-9) INAPPLICABLE, NEVER USED' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE a51eu     -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO/NEVER USED'
                  1='(1) YES' ;
  VALUE a51lu     -9='(-9) INAPPLICABLE, NEVER USED' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO' 1='(1) YES' ;
  VALUE a51age    -9='(-9) INAPPLICABLE, NEVER USED' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE a52eu     -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO/NEVER USED'
                  1='(1) YES' ;
  VALUE a52oth    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) MIDOL/BENEDRYL'
                  2='(2) EXTRA STRENGTH TYLENOL NIGHT TIME' 3='(3) TYLENOL'
                  4='(4) BENEDRYL/CAFFEINE PILLS' 5='(5) TAGAMENT' 6='(6) NYQUIL'
                  7='(7) COUGH MEDICINE, COUGH SYRUP' 8='(8) ZOLOFT 200' 9='(9) CODINE'
                  10='(10) CAFFEINE PILLS, NO DOZ, CAFFEINE'
                  11='(11) IBUPROFEN AND MIDOL' 12='(12) MINITHINS' 13='(13) ASPIRIN'
                  14='(14) EPIDREINE' 15='(15) DIET PILLS' 16='(16) TYLENOL WITH CODEINE'
                  17='(17) MULTIVITAMIN' 18='(18) PAIN PILLS'
                  19='(19) ADVIL, IBUPROFIN, MOTRIN' 20='(20) ELAVIL' 21='(21) DRAMAMIN'
                  22='(22) UNISOM' 23='(23) AFFEDRIN' 24='(24) ALEVE' 25='(25) SLEEPING PILLS'
                  26='(26) XANAX' 27='(27) VICODIN' 28='(28) DARVACOT' ;
  VALUE a52lu     -9='(-9) INAPPLICABLE, NEVER USED' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO' 1='(1) YES' ;
  VALUE a52age    -9='(-9) INAPPLICABLE, NEVER USED' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE a53eu     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 0='(0) NO/NEVER USED' 1='(1) YES' ;
  VALUE a53lu     -9='(-9) INAPPLICABLE, NEVER USED' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO' 1='(1) YES' ;
  VALUE a53age    -9='(-9) INAPPLICABLE, NEVER USED' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE a54eu     -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO/NEVER USED'
                  1='(1) YES' ;
  VALUE a54lu     -9='(-9) INAPPLICABLE, NEVER USED' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO' 1='(1) YES' ;
  VALUE a54age    -9='(-9) INAPPLICABLE, NEVER USED' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE a55eu     -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO/NEVER USED'
                  1='(1) YES' ;
  VALUE a55lu     -9='(-9) INAPPLICABLE, NEVER USED' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO' 1='(1) YES' ;
  VALUE a55age    -9='(-9) INAPPLICABLE, NEVER USED' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE a56eu     -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO/NEVER USED'
                  1='(1) YES' ;
  VALUE a56lu     -9='(-9) INAPPLICABLE, NEVER USED' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO' 1='(1) YES' ;
  VALUE a56age    -9='(-9) INAPPLICABLE, NEVER USED' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE a57fffff  -7='(-7) NOT ASCERTAINED' 0='(0) NO SUBSTANCE OF CHOICE' 40='(40) CRACK'
                  41='(41) COCAINE' 42='(42) HEROIN' 43='(43) METHADONE-NON-TX'
                  44='(44) OTHER OPIATES' 45='(45) BARBITURATES' 46='(46) BENZODIZEPINES'
                  47='(47) OTHER SEDATIVES/HYPNOTICS' 48='(48) AMPHETAMINES'
                  49='(49) MARIJUANA, HASHISH, THC' 50='(50) HALLUCINOGENS'
                  51='(51) INHALANTS' 52='(52) OVER-THE-COUNTER' 53='(53) ALCOHOL'
                  54='(54) TOBACCO' 55='(55) OTHER DRUG1' 56='(56) OTHER DRUG2'
                  96='(96) MULTIPLE DRUGS NAMED' ;
  VALUE a58a      -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO' 1='(1) YES' ;
  VALUE a58b      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 0='(0) NO' 1='(1) YES' ;
  VALUE a58c      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) DAILY' 2='(2) REGULARLY BUT NOT DAILY'
                  3='(3) SPORADICALLY' ;
  VALUE a59fffff  -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO' 1='(1) YES' ;
  VALUE a60a      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 0='(0) NO' 1='(1) YES' ;
  VALUE a60b      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 0='(0) NO' 1='(1) YES' ;
  VALUE a60c      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) YES-NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 0='(0) NO' 1='(1) YES, TYPE NOT SPECIFIED'
                  2='(2) BREATH, BREATHALIZER' 3='(3) DRUG PANEL 5-EMIT' 4='(4) YES-RPR' ;
  VALUE a61fffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) ONE TIME ONLY'
                  2='(2) MORE THAN ONCE, AT REGULAR INTERVALS'
                  3='(3) MORE THAN ONCE, RANDOMLY (TIME UNKNOWN T'
                  4='(4) MORE THAN ONCE, BOTH AT REGULAR INTERVAL'
                  5='(5) MORE THAN ONCE, INTERVALS NOT SPECIFIED'
                  8='(8) OTHER, NOT FURTHER CODED' ;
  VALUE a62fop    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) POSITIVE RESULTS' ;
  VALUE a62fco    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) POSITIVE RESULTS' ;
  VALUE a62fthc   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) POSITIVE RESULTS' ;
  VALUE a62foth   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) POSITIVE RESULTS' ;
  VALUE a62lop    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) POSITIVE RESULTS' ;
  VALUE a62lco    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) POSITIVE RESULTS' ;
  VALUE a62lthc   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) POSITIVE RESULTS' ;
  VALUE a62loth   -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) POSITIVE RESULTS' ;
  VALUE a63fffff  -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' -4='(-4) OTHER'
                  0='(0) NO PRIOR TREATMENT EPISODES' ;
  VALUE a64fffff  -9='(-9) INAPPLICABLE' -7='(-7) NOT ASCERTAINED' -1='(-1) Lifetime' ;
  VALUE a65fffff  -9='(-9) INAPPLICABLE, LEAVE TABLE BLANK' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  0='(0) NONE (REPORTED OR LOGICALLY ASSIGNED)'
                  1='(1) YES, ONE EPISODE REPORTED'
                  2='(2) YES, TWO EPISODES REPORTED'
                  3='(3) YES, THREE EPISODES REPORTED'
                  4='(4) YES, FOUR EPISODES REPORTED'
                  5='(5) YES, FIVE EPISODES REPORTED'
                  6='(6) YES, SIX EPISODES, CONTINUATION TABLE US' ;
  VALUE a65ar     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) ALCOHOL ABUSE ONLY' 2='(2) DRUG ABUSE ONLY'
                  3='(3) COMBINED ALCOHOL AND DRUG ABUSE' ;
  VALUE a65af     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) HERE' 2='(2) ELSEWHERE' ;
  VALUE a65at     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) INPATIENT OR RESIDENTIAL'
                  2='(2) OUTPATIENT' 3='(3) DETOX' ;
  VALUE a65ad     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 0='(0) DID NOT COMPLETE TREATMENT'
                  1='(1) COMPLETED TREATMENT' 2='(2) TRANSFERRED TO THIS FACILITY' ;
  VALUE a65br     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) ALCOHOL ABUSE ONLY' 2='(2) DRUG ABUSE ONLY'
                  3='(3) COMBINED ALCOHOL AND DRUG ABUSE' ;
  VALUE a65bf     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) HERE' 2='(2) ELSEWHERE' ;
  VALUE a65bt     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) INPATIENT OR RESIDENTIAL'
                  2='(2) OUTPATIENT' 3='(3) DETOX' ;
  VALUE a65bd     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 0='(0) DID NOT COMPLETE TREATMENT'
                  1='(1) COMPLETED TREATMENT' 2='(2) TRANSFERRED TO THIS FACILITY' ;
  VALUE a65cr     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) ALCOHOL ABUSE ONLY' 2='(2) DRUG ABUSE ONLY'
                  3='(3) COMBINED ALCOHOL AND DRUG ABUSE' ;
  VALUE a65cf     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) HERE' 2='(2) ELSEWHERE' ;
  VALUE a65ct     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) INPATIENT OR RESIDENTIAL'
                  2='(2) OUTPATIENT' 3='(3) DETOX' ;
  VALUE a65cd     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 0='(0) DID NOT COMPLETE TREATMENT'
                  1='(1) COMPLETED TREATMENT' 2='(2) TRANSFERRED TO THIS FACILITY' ;
  VALUE a65dr     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) ALCOHOL ABUSE ONLY' 2='(2) DRUG ABUSE ONLY'
                  3='(3) COMBINED ALCOHOL AND DRUG ABUSE' ;
  VALUE a65df     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) HERE' 2='(2) ELSEWHERE' ;
  VALUE a65dt     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) INPATIENT OR RESIDENTIAL'
                  2='(2) OUTPATIENT' 3='(3) DETOX' ;
  VALUE a65dd     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 0='(0) DID NOT COMPLETE TREATMENT'
                  1='(1) COMPLETED TREATMENT' 2='(2) TRANSFERRED TO THIS FACILITY' ;
  VALUE a65er     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) ALCOHOL ABUSE ONLY' 2='(2) DRUG ABUSE ONLY'
                  3='(3) COMBINED ALCOHOL AND DRUG ABUSE' ;
  VALUE a65ef     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) HERE' 2='(2) ELSEWHERE' ;
  VALUE a65et     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) INPATIENT OR RESIDENTIAL'
                  2='(2) OUTPATIENT' 3='(3) DETOX' ;
  VALUE a65ed     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 0='(0) DID NOT COMPLETE TREATMENT'
                  1='(1) COMPLETED TREATMENT' 2='(2) TRANSFERRED TO THIS FACILITY' ;
  VALUE a65fr     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) ALCOHOL ABUSE ONLY' 2='(2) DRUG ABUSE ONLY'
                  3='(3) COMBINED ALCOHOL AND DRUG ABUSE' ;
  VALUE a65ff     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) HERE' 2='(2) ELSEWHERE' ;
  VALUE a65ft     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) INPATIENT OR RESIDENTIAL'
                  2='(2) OUTPATIENT' 3='(3) DETOX' ;
  VALUE a65fd     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 0='(0) DID NOT COMPLETE TREATMENT'
                  1='(1) COMPLETED TREATMENT' 2='(2) TRANSFERRED TO THIS FACILITY' ;
  VALUE a65gr     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) ALCOHOL ABUSE ONLY' 2='(2) DRUG ABUSE ONLY'
                  3='(3) COMBINED ALCOHOL AND DRUG ABUSE' ;
  VALUE a65gf     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) HERE' 2='(2) ELSEWHERE' ;
  VALUE a65gt     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) INPATIENT OR RESIDENTIAL'
                  2='(2) OUTPATIENT' 3='(3) DETOX' ;
  VALUE a65gd     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 0='(0) DID NOT COMPLETE TREATMENT'
                  1='(1) COMPLETED TREATMENT' 2='(2) TRANSFERRED TO THIS FACILITY' ;
  VALUE a65hr     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) ALCOHOL ABUSE ONLY' 2='(2) DRUG ABUSE ONLY'
                  3='(3) COMBINED ALCOHOL AND DRUG ABUSE' ;
  VALUE a65hf     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) HERE' 2='(2) ELSEWHERE' ;
  VALUE a65ht     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) INPATIENT OR RESIDENTIAL'
                  2='(2) OUTPATIENT' 3='(3) DETOX' ;
  VALUE a65hd     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 0='(0) DID NOT COMPLETE TREATMENT'
                  1='(1) COMPLETED TREATMENT' 2='(2) TRANSFERRED TO THIS FACILITY' ;
  VALUE a65ir     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) ALCOHOL ABUSE ONLY' 2='(2) DRUG ABUSE ONLY'
                  3='(3) COMBINED ALCOHOL AND DRUG ABUSE' ;
  VALUE a65if     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) HERE' 2='(2) ELSEWHERE' ;
  VALUE a65it     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) INPATIENT OR RESIDENTIAL'
                  2='(2) OUTPATIENT' 3='(3) DETOX' ;
  VALUE a65id     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 0='(0) DID NOT COMPLETE TREATMENT'
                  1='(1) COMPLETED TREATMENT' 2='(2) TRANSFERRED TO THIS FACILITY' ;
  VALUE a65jr     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) ALCOHOL ABUSE ONLY' 2='(2) DRUG ABUSE ONLY'
                  3='(3) COMBINED ALCOHOL AND DRUG ABUSE' ;
  VALUE a65jf     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) HERE' 2='(2) ELSEWHERE' ;
  VALUE a65jt     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) INPATIENT OR RESIDENTIAL'
                  2='(2) OUTPATIENT' 3='(3) DETOX' ;
  VALUE a65jd     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 0='(0) DID NOT COMPLETE TREATMENT'
                  1='(1) COMPLETED TREATMENT' 2='(2) TRANSFERRED TO THIS FACILITY' ;
  VALUE a66fffff  -9='(-9) INAPPLICABLE, CLIENT TYPE IS METH DIS OR' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED/UNABLE TO DETERMINE' -6='(-6) DON''T KNOW' ;
  VALUE a67a      -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO'
                  1='(1) YES, IN THIS FACILITY'
                  2='(2) YES, SOMETIMES HERE, SOMETIMES ELSEWHERE'
                  3='(3) YES, NOT IN THIS FACILTY' ;
  VALUE a67an     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE a67b      -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO'
                  1='(1) YES, IN THIS FACILITY'
                  2='(2) YES, SOMETIMES HERE, SOMETIMES ELSEWHERE'
                  3='(3) YES, NOT IN THIS FACILITY' ;
  VALUE a67bn     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) UNKNOWN'
                  -6='(-6) DON''T KNOW' ;
  VALUE a67c      -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO'
                  1='(1) YES, IN THIS FACILITY'
                  2='(2) YES, SOMETIMES HERE, SOMETIMES ELSEWHERE'
                  3='(3) YES, NOT IN THIS FACILTY' ;
  VALUE a67cn     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE a67d      -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO'
                  1='(1) YES, IN THIS FACILITY'
                  2='(2) YES, SOMETIMES HERE, SOMETIMES ELSEWHERE'
                  3='(3) YES, NOT IN THIS FACILTY' ;
  VALUE a67dn     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE a67e      -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO'
                  1='(1) YES, IN THIS FACILITY'
                  2='(2) YES, SOMETIMES HERE, SOMETIMES ELSEWHERE'
                  3='(3) YES, NOT IN THIS FACILTY' ;
  VALUE a67f      -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO'
                  1='(1) YES, IN THIS FACILITY'
                  2='(2) YES, SOMETIMES HERE, SOMETIMES ELSEWHERE'
                  3='(3) YES, NOT IN THIS FACILTY' ;
  VALUE a67g      -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO'
                  1='(1) YES, IN THIS FACILITY'
                  2='(2) YES, SOMETIMES HERE, SOMETIMES ELSEWHERE'
                  3='(3) YES, NOT IN THIS FACILTY' ;
  VALUE a67h      -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO'
                  1='(1) YES, IN THIS FACILITY'
                  2='(2) YES, SOMETIMES HERE, SOMETIMES ELSEWHERE'
                  3='(3) YES, NOT IN THIS FACILTY' ;
  VALUE a67i      -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO'
                  1='(1) YES, IN THIS FACILITY'
                  2='(2) YES, SOMETIMES HERE, SOMETIMES ELSEWHERE'
                  3='(3) YES, NOT IN THIS FACILTY' ;
  VALUE a67j      -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO'
                  1='(1) YES, IN THIS FACILITY'
                  2='(2) YES, SOMETIMES HERE, SOMETIMES ELSEWHERE'
                  3='(3) YES, NOT IN THIS FACILTY' ;
  VALUE a67k      -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO'
                  1='(1) YES, IN THIS FACILITY'
                  2='(2) YES, SOMETIMES HERE, SOMETIMES ELSEWHERE'
                  3='(3) YES, NOT IN THIS FACILTY' ;
  VALUE a67l      -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO'
                  1='(1) YES, IN THIS FACILITY'
                  2='(2) YES, SOMETIMES HERE, SOMETIMES ELSEWHERE'
                  3='(3) YES, NOT IN THIS FACILTY' ;
  VALUE a67m      -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO'
                  1='(1) YES, IN THIS FACILITY'
                  2='(2) YES, SOMETIMES HERE, SOMETIMES ELSEWHERE'
                  3='(3) YES, NOT IN THIS FACILTY' ;
  VALUE a67n      -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO'
                  1='(1) YES, IN THIS FACILITY'
                  2='(2) YES, SOMETIMES HERE, SOMETIMES ELSEWHERE'
                  3='(3) YES, NOT IN THIS FACILTY' ;
  VALUE a67o      -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO'
                  1='(1) YES, IN THIS FACILITY'
                  2='(2) YES, SOMETIMES HERE, SOMETIMES ELSEWHERE'
                  3='(3) YES, NOT IN THIS FACILTY' ;
  VALUE a67p      -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO'
                  1='(1) YES, IN THIS FACILITY'
                  2='(2) YES, SOMETIMES HERE, SOMETIMES ELSEWHERE'
                  3='(3) YES, NOT IN THIS FACILTY' ;
  VALUE a67q      -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO'
                  1='(1) YES, IN THIS FACILITY'
                  2='(2) YES, SOMETIMES HERE, SOMETIMES ELSEWHERE'
                  3='(3) YES, NOT IN THIS FACILITY' ;
  VALUE a67r      -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO'
                  1='(1) YES, IN THIS FACILITY'
                  2='(2) YES, SOMETIMES HERE, SOMETIMES ELSEWHERE'
                  3='(3) YES, NOT IN THIS FACILITY' ;
  VALUE a67s      -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO'
                  1='(1) YES, IN THIS FACILITY'
                  2='(2) YES, SOMETIMES HERE, SOMETIMES ELSEWHERE'
                  3='(3) YES, NOT IN THIS FACILITY' ;
  VALUE a67t      -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO'
                  1='(1) YES, IN THIS FACILITY'
                  2='(2) YES, SOMETIMES HERE, SOMETIMES ELSEWHERE'
                  3='(3) YES, NOT IN THIS FACILITY' ;
  VALUE a68fffff  -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO'
                  1='(1) YES, ONE LISTED BELOW' 2='(2) YES, TWO LISTED BELOW'
                  3='(3) YES, THREE LISTED BELOW'
                  4='(4) YES, MORE THAN THREE, SEE COMMENTS' ;
  VALUE a68a1fff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) AMBIEN' 2='(2) ANAPROX' 3='(3) BROMATAPP'
                  4='(4) BUSPER' 5='(5) CLARITIN D' 6='(6) CLONIDINE' 7='(7) CYLERT'
                  8='(8) DESYREL' 9='(9) DEPAKOTE' 10='(10) DOXYCYCLINE' 11='(11) EFFEXOR'
                  12='(12) EPIVIR' 13='(13) EYE DROPS' 14='(14) IBUPROFEN, ADVIL'
                  15='(15) KLONAPIN' 16='(16) LOMOTIL' 17='(17) MOTRIN' 18='(18) NAPROSYN, ALEVE'
                  19='(19) NORVASC' 20='(20) PAXIL' 21='(21) PENICILLIN, PEN VK' 22='(22) PROZAC'
                  23='(23) TRAZODONE' 24='(24) TRIMETHOPRIM' 25='(25) TUSSI'
                  26='(26) TYLENOL, ACETAMINOPHEN' 27='(27) VENTOLIN' 28='(28) ZERIT'
                  29='(29) GULAFED CAPS' 30='(30) KETLEX' 31='(31) DIPHENHYDRAMINE'
                  32='(32) AMITRIPTYLINE, ELAVIL' 33='(33) CARISOPRODOL' 34='(34) CODEINE'
                  35='(35) DILATIN' 36='(36) VALIUM' 37='(37) TEGRETOL' 38='(38) XANAX'
                  39='(39) DEMORAL' 40='(40) VISTAREL, VISTARIL, VISTORIL' 41='(41) TORADOL'
                  42='(42) ANTABUSE' 43='(43) EUCHOR' 44='(44) IMOPRAMINE' 45='(45) DEPOLATE'
                  46='(46) TROZODUC' 47='(47) DCYOHBO' 48='(48) PERCIDAN' 49='(49) DARVOCET'
                  50='(50) TYLOX' 51='(51) DESIPRAMINE' 52='(52) ZANTAC' 53='(53) BENTAL'
                  54='(54) LITHIUM' 55='(55) NAVANE' 56='(56) COGENTIN' 57='(57) LIBRIUM'
                  58='(58) ATIVAN' 59='(59) HUMULIN' 60='(60) TYLENOL 325' 61='(61) ZOVIRAX'
                  62='(62) CATAPRES PATCH' 63='(63) K-DUR' 64='(64) TENORNIN'
                  65='(65) MOTRIN (600)' 66='(66) THERAHIST COUGH SYRUP' 67='(67) KEFLEX'
                  68='(68) PROCARDIA' 69='(69) SINEQUIN' 70='(70) ISONIAZID' 71='(71) DOXEPIN'
                  72='(72) IMIPANINE' 73='(73) HYDROXYZINE' 74='(74) DISULFIRAM'
                  75='(75) AXID, ACID CONTROL MEDICINE' 76='(76) ZOLOFT' 77='(77) VICODIN'
                  78='(78) LORAZEPAN' 79='(79) PYRIDOXINE' 80='(80) TRIMAX' 81='(81) CEFZIL'
                  82='(82) GUIATUSS' 83='(83) PHENYLPROP' 84='(84) ALBUTEROL' 85='(85) BECONASE'
                  86='(86) DURATUSS' 87='(87) FLUORINONILE CREAM' 88='(88) GLYBURIDE'
                  89='(89) PSYCHOTROPIC MEDS' 90='(90) SOMA' 91='(91) VEETIDS' 92='(92) PLENDIL'
                  93='(93) HYDROCHOROTLIAZIDE' 94='(94) FELODIPINE'
                  95='(95) PSEUDOEPHEDRINE, SUDAFED' 96='(96) DIFLUCAN' 97='(97) RIFAMPIN'
                  98='(98) RETROVIR' 99='(99) ATORANQUINE' 100='(100) TOFRANIL'
                  101='(101) TRILAFON' 102='(102) DIZERYPERMIM' 103='(103) PRALASAC'
                  104='(104) ALACTONE' 105='(105) VITAMINS, OR A VITAMIN' 106='(106) ASPIRIN'
                  107='(107) IRON, FERROS SULFATE' 108='(108) CHLORDIAZEPOXIDE'
                  109='(109) MAALOX' 110='(110) PRENATAL VITAMINS' 111='(111) AMOXICILLIN'
                  112='(112) VOLTAREN' 113='(113) ERYTHROMYCEN' 114='(114) PROMETHAZINE'
                  115='(115) METRUNIDZOLE' 116='(116) ATENOLOL' 117='(117) ULTRAM'
                  118='(118) METFORMIN' 119='(119) INSULIN' 120='(120) BACTRACIN' 121='(121) FLAGYL'
                  122='(122) CIPROFLOXCIN' 123='(123) PHENEGAN'
                  124='(124) FERROUS SULFATE (USE 107)' 125='(125) LABRAMYCIN'
                  126='(126) TYLENOL WITH CODEINE, TYLENOL #3' 127='(127) HALDOL'
                  128='(128) BENEDRYL' 129='(129) CHLORTRIMETON' 130='(130) SMZ/TMD'
                  131='(131) EQUATE' 132='(132) SERZONE' 133='(133) NALDOCON' 134='(134) SURFAK'
                  135='(135) PROVENTIL INHALER/NEBULIZER' 136='(136) TORODAL'
                  137='(137) AMOXIL' 138='(138) METHYLPRED' 139='(139) ESKALITH'
                  140='(140) PHENOBARBITOL' 141='(141) WELLBUTRIN' 142='(142) REVIA'
                  143='(143) ANTIBIOTICS, NOT NAMED' 144='(144) MICRONASE'
                  145='(145) LOPRESSOR' 146='(146) BUSBON' 147='(147) ASTHMA INHALER/MEDICINES'
                  148='(148) GLYIZIDE (FOR DIABETICS)' 149='(149) AZT' 150='(150) RISPERDAL'
                  151='(151) BEROCCA' 152='(152) MYLANTA' 153='(153) TETRACYCLINE'
                  154='(154) ANTIPYRLBENZOCAINE' 155='(155) E-MYCIN' 156='(156) TRI-LEVLEN'
                  157='(157) TRIMETHOBENZAMIDE' 158='(158) PROPRAPH' 159='(159) PISCARDIA'
                  160='(160) THORAZINE' 161='(161) PREMARIN' 162='(162) FAMVIR'
                  163='(163) DESORIMETASONE' 164='(164) ANUSOL' 165='(165) SENNA'
                  166='(166) HYDROGEN PEROXIDE' 167='(167) BENZOYL PEROXIDE'
                  168='(168) TOLNAFLATE' 169='(169) LACHYDRIN OR LACHYDIA'
                  170='(170) HYDERZINE' 171='(171) EURAX CREAM' 172='(172) ATARAX' 173='(173) CIPRO'
                  174='(174) MYCFLEX CREAM (MYCELEX CREAM?)' 175='(175) TAGAMET'
                  176='(176) PAMELOR' 177='(177) NORTRIPTYLYN' 178='(178) OLANZAPINE'
                  179='(179) NALTRAVONE' 180='(180) NALTAXORE' 181='(181) SERTRALINE'
                  182='(182) HEART MEDICINE' 183='(183) BLOOD PRESSURE MEDICINE'
                  184='(184) MELLARIL' 185='(185) PROLIXIN' 186='(186) PROLIXIN DECANDATE'
                  187='(187) RITALIN' 188='(188) SUMUCIN (FOR ACNE)' 189='(189) ADDERALL'
                  190='(190) LITHOBID' 191='(191) CALAN RS' 192='(192) TRAYENE' 193='(193) ZOCORE'
                  194='(194) ANATOL' 195='(195) THYROID MEDICINE' 196='(196) ACCUDE' 197='(197) AMBU'
                  198='(198) ALDACTONE' 199='(199) INDEROL' 200='(200) HYDROCOO/APAP'
                  201='(201) DIAZEPAM' 202='(202) LORCET' 203='(203) TOCOZ' 204='(204) FULICUN'
                  205='(205) INDOCIN' 206='(206) GLUCATROL' 207='(207) FLEXERIL' 208='(208) THIAMINE'
                  209='(209) CARAFATE' 210='(210) BROMOCRIPTINE' 211='(211) ELAVIL'
                  212='(212) FUROSEMIDE' 213='(213) LUTENSIN' 214='(214) EMYACIN'
                  215='(215) PREDNISONE' 216='(216) SCHIZOPRENIA MEDS' 217='(217) THEODUR'
                  218='(218) PROVESTIL' 219='(219) CYNTROID' 220='(220) NPD HUMILIN'
                  221='(221) STODBID' 222='(222) RETIMO' 223='(223) VIDEX' 224='(224) FIORERAL'
                  225='(225) SYNTHROID' 226='(226) TB MEDS' 227='(227) MORPHINE'
                  228='(228) NICLOXACILLIN' 229='(229) COLACE' 230='(230) COMPAZIN'
                  231='(231) LOTRIMIN' 232='(232) PRONEUHL' 233='(233) PROVERTAD' 234='(234) INH'
                  235='(235) DAXIL' 236='(236) CLIMDAMYCIN' 237='(237) INIVASE' 238='(238) EPIRIE'
                  239='(239) SYNOLAR' 240='(240) AUGMENTIN' 241='(241) DAYPRO' 242='(242) ESTROGEN'
                  243='(243) ROBAXIN' 244='(244) BICILLIN' 245='(245) ROBITUSSIN' 246='(246) PITOCIN'
                  247='(247) FESOG' 248='(248) PNV' 249='(249) PROVERA' 250='(250) TRILPONT'
                  251='(251) PROPANDOL' 252='(252) AMPICILLIN' 253='(253) SLOHID' 254='(254) PEN UK'
                  255='(255) VASOTEX' 256='(256) AEROLBID' 257='(257) CARDIXEM' 258='(258) LITIBIA'
                  259='(259) SEREVENT' 260='(260) REMERON' 261='(261) BADOFEN' 262='(262) SUCRALFATE'
                  263='(263) NAAROSYN' 264='(264) REBAXIN' 265='(265) ATROVENT'
                  266='(266) DIANZAPINE' 267='(267) CUREX' 268='(268) FE SO4' 269='(269) NIFEDIPINE'
                  270='(270) ALKA SELTZER' 271='(271) NAPROXEN' 272='(272) SUPHEDRINE'
                  273='(273) DARVON' 274='(274) ZYPREXA' 275='(275) PRINCIPEN' 276='(276) BIAXIN'
                  277='(277) ATRIPALIN' 278='(278) PERCOCERT' 279='(279) RELATEN'
                  280='(280) MILK OF MAGNESIA' 281='(281) ZESTRIOL' 282='(282) VALPROIC'
                  283='(283) REZULIN' 284='(284) CARDIZEN' 285='(285) AIPRAZOLAM'
                  286='(286) DIFLUCON' 287='(287) ACYCLOVIN' 288='(288) SELSUM LOTION'
                  289='(289) CEPHALEXIN' 290='(290) TRIAMICINOLONE' 291='(291) FLUVOYAMINE'
                  292='(292) DIVALPROEX' 293='(293) ENTEX' 294='(294) BACTRIM D.S'
                  295='(295) NICARDIPINE' 296='(296) VERAPAMIL' 297='(297) NOVOLIN'
                  298='(298) TRIVIL' 299='(299) BUTHEONTROL PILLS' 300='(300) PREVACID'
                  301='(301) IMURAN' 302='(302) CEFTIN' 303='(303) PHENYTOIN' 304='(304) FLUOXETINE'
                  305='(305) PECID AC' 306='(306) HABOPERIDOL' 307='(307) BENZTROPINE'
                  308='(308) THIOTHIZENE' 309='(309) CERENTIL' 310='(310) PRITOXEC'
                  311='(311) SULFANETHOXZOLE' 312='(312) SYMMETREL' 313='(313) ACETAMINOPHEN'
                  314='(314) PROPULSID' 315='(315) CLOZARIL' 316='(316) TRITEC' 317='(317) ISPERDONE'
                  318='(318) VICODRID' 319='(319) KOZOR' 320='(320) NELFINAVIE' 321='(321) CLARODENE'
                  322='(322) TEGIOXAL' 323='(323) AZITHROMYEIN' 324='(324) NORTRIPTICINE'
                  325='(325) FERNOSEMIDE' 326='(326) ALPRAZOLAM' 327='(327) ROXICET'
                  328='(328) LISINOPRIL' 329='(329) CHLORDIAZOPOXIDE' 330='(330) DENCILLIN'
                  331='(331) NASAL SPRAY' 332='(332) DIMIPRAMINE' 333='(333) FLENEMIL'
                  334='(334) HODINE XL' 335='(335) ACUPRIL' 336='(336) HOZOL' 337='(337) DUIRETIC'
                  338='(338) DIMOXICYLEN' 339='(339) QUEMAPRIL HCL ACCUPRIL'
                  340='(340) DALMANE' 341='(341) DELTASONE' 342='(342) HYDROXYCLORS'
                  343='(343) HALCION' 344='(344) HYDRECED' 345='(345) PRILOSEE'
                  346='(346) GLYBURIDEHOZOL' 347='(347) PONDIMIN' 348='(348) IONAMIN'
                  349='(349) BECLOVENT' 350='(350) CILYBURIDE' 351='(351) NYQUIL'
                  352='(352) DYSTHYMIA' 353='(353) ALLOPUINO' 354='(354) SERAZ' 355='(355) ATTAVAT'
                  356='(356) NITROGLYCERIN' 357='(357) RYTHMEL' 358='(358) PROCANAMIDE'
                  359='(359) REGLAN' 360='(360) CYCLOBENZAPRIN' 361='(361) CHLORPROMAZINE'
                  362='(362) KEMADRINE' 363='(363) FLURBIPROFIN' 364='(364) DIDIFENAC'
                  365='(365) IRI-CHROMALSANE' 366='(366) METOROLOL TARTRATE'
                  367='(367) DUCOSOTE' 368='(368) ROXIPRIN' 369='(369) DICLOXACILLIN'
                  370='(370) POTASSIUM' 371='(371) SUDAFED' 372='(372) IRIAZLSLEM'
                  373='(373) LOESTRINE' 374='(374) COUMODIN' 375='(375) VENTYLIN'
                  376='(376) DOCUISCITE' 377='(377) ZYPRIZA' 378='(378) UNISOM' 379='(379) ALEVE'
                  380='(380) MYSOLENE' 381='(381) PEGRATOL' 382='(382) AMOC/CLORAL/AUGMERTIA'
                  383='(383) LASIX' 384='(384) MONOPRIL' 385='(385) BACTRIA' 386='(386) AUGMENTIA'
                  387='(387) ASA' 388='(388) ALPROZOLAM' 389='(389) METRO CARBROL'
                  390='(390) ORUVAIL' 391='(391) PRILOSRC' 392='(392) LOXITANE' 393='(393) ZYPROXIN'
                  394='(394) BERPLEX PLUS' 395='(395) KETOPROFEN' 396='(396) LOPERAMIDE'
                  397='(397) VERTIDO' 398='(398) BRONCLODILATOR' 399='(399) CEFTER'
                  400='(400) HABITROL PATCH' 401='(401) CAPTOPRIL' 402='(402) PREPHENAZINE'
                  403='(403) NAXIDE' 404='(404) CLONAZEPAM' 405='(405) ZANAX' 406='(406) DEREYL'
                  407='(407) ZINEGUAN' 408='(408) DIFLUM' 409='(409) DAPCN' 410='(410) BACTRUM'
                  411='(411) TEGAMET' 412='(412) LIORASIL' 413='(413) NEFAZODONE'
                  414='(414) CONGISTAID' 415='(415) NALTREXONE' 416='(416) LEVOGUIN'
                  417='(417) GLIPIZID' 418='(418) SELDANE' 419='(419) LUVOX' 420='(420) ADALACK'
                  421='(421) PAXIN' 422='(422) CAPRICE III' 423='(423) LODENE' 424='(424) PERCOCET'
                  425='(425) CILIQUAN' 426='(426) SONBIEN' 427='(427) LICOZ' 428='(428) PEPAD'
                  429='(429) HYDROCODONE' 430='(430) VALPORIC ACID' 431='(431) PVK'
                  432='(432) FIOSOCAT' 433='(433) PROPOXY-NAPAP' 434='(434) DEBROX'
                  435='(435) MIDRIN' 436='(436) MICONAZOLE' 437='(437) ROSPERIDONE'
                  438='(438) PROPRANOLOL' 439='(439) HIZONE' 440='(440) PREMADEN'
                  441='(441) KLONIDINE' 442='(442) LEVOTHYROXINE SODIUM'
                  443='(443) PHENCIZOPYRDINE' 444='(444) TRUPROFEN' 445='(445) FOLATE'
                  446='(446) PAN VA' 447='(447) DIPHENOXYLATE' 448='(448) NICOTINE REFREM'
                  449='(449) TIAC' 450='(450) HZMACORT' 451='(451) NAPRALAN' 452='(452) TEMAXIPAN'
                  453='(453) RIFADIN' 454='(454) ZYRTEX' 455='(455) MEVACOR' 456='(456) VIFLEX'
                  457='(457) COMPAZINE' 458='(458) HCTZ' 459='(459) K-LYTE' 460='(460) DIABETA'
                  461='(461) ACIFED' 462='(462) CLORIDINE' 463='(463) PYRIMETHAMINE'
                  464='(464) SLEEPING PILLS' 465='(465) CAPTAPRIL' 466='(466) TIMOLOLMALEATG'
                  467='(467) CIMETIDINE' 468='(468) TRYSOPT' 469='(469) HYDROCORTISONE'
                  470='(470) METHEGRINE' 471='(471) TERAZOL' 472='(472) CLIOCIN VAGINAL CREAM'
                  473='(473) COMBIVER' 474='(474) PHERONOL' 475='(475) ULTRAVALT CREAM'
                  476='(476) LISINOGNIL' 477='(477) OXYCANTIN' 478='(478) CRIXIVCEN' 479='(479) TBID'
                  480='(480) VERCERIL' 481='(481) DILTEAZEN' 482='(482) DEXAMETHASON'
                  483='(483) NICITROL' 484='(484) DESOROL' 485='(485) FIORPAP' 486='(486) D3I'
                  487='(487) STAVODINE' 488='(488) PROCARDIN' 489='(489) STELAZINE'
                  490='(490) ZALATAN' 491='(491) VANCENASE' 492='(492) BUTRIN' 493='(493) ESSEVOR'
                  494='(494) MATAIN' 495='(495) NICODERM PATCH' 496='(496) PERCOCOET'
                  497='(497) SANDOGLOBULIN INFUSION' 498='(498) MSAID' 499='(499) DONNATAL'
                  500='(500) TRESIDONE' 501='(501) PREMETHOZINE' 502='(502) CODAMINE SYRUP'
                  503='(503) FLAPHENOZINE' 504='(504) CUMIDIN' 505='(505) HYTRIN'
                  506='(506) POLOMAINE' 507='(507) TINANCIN' 508='(508) DIOVAN' 509='(509) IBU'
                  510='(510) TROPOMINE' 511='(511) LANOXIN' 512='(512) AMITRIPTY'
                  513='(513) ALPRAZALAN' 514='(514) KERLON' ;
  VALUE a68a2fff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) AMBIEN' 2='(2) ANAPROX' 3='(3) BROMATAPP'
                  4='(4) BUSPER' 5='(5) CLARITIN D' 6='(6) CLONIDINE' 7='(7) CYLERT'
                  8='(8) DESYREL' 9='(9) DEPAKOTE' 10='(10) DOXYCYCLINE' 11='(11) EFFEXOR'
                  12='(12) EPIVIR' 13='(13) EYE DROPS' 14='(14) IBUPROFEN, ADVIL'
                  15='(15) KLONAPIN' 16='(16) LOMOTIL' 17='(17) MOTRIN' 18='(18) NAPROSYN, ALEVE'
                  19='(19) NORVASC' 20='(20) PAXIL' 21='(21) PENICILLIN, PEN VK' 22='(22) PROZAC'
                  23='(23) TRAZODONE' 24='(24) TRIMETHOPRIM' 25='(25) TUSSI'
                  26='(26) TYLENOL, ACETAMINOPHEN' 27='(27) VENTOLIN' 28='(28) ZERIT'
                  29='(29) GULAFED CAPS' 30='(30) KETLEX' 31='(31) DIPHENHYDRAMINE'
                  32='(32) AMITRIPTYLINE, ELAVIL' 33='(33) CARISOPRODOL' 34='(34) CODEINE'
                  35='(35) DILATIN' 36='(36) VALIUM' 37='(37) TEGRETOL' 38='(38) XANAX'
                  39='(39) DEMORAL' 40='(40) VISTAREL, VISTARIL, VISTORIL' 41='(41) TORADOL'
                  42='(42) ANTABUSE' 43='(43) EUCHOR' 44='(44) IMOPRAMINE' 45='(45) DEPOLATE'
                  46='(46) TROZODUC' 47='(47) DCYOHBO' 48='(48) PERCIDAN' 49='(49) DARVOCET'
                  50='(50) TYLOX' 51='(51) DESIPRAMINE' 52='(52) ZANTAC' 53='(53) BENTAL'
                  54='(54) LITHIUM' 55='(55) NAVANE' 56='(56) COGENTIN' 57='(57) LIBRIUM'
                  58='(58) ATIVAN' 59='(59) HUMULIN' 60='(60) TYLENOL 325' 61='(61) ZOVIRAX'
                  62='(62) CATAPRES PATCH' 63='(63) K-DUR' 64='(64) TENORNIN'
                  65='(65) MOTRIN (600)' 66='(66) THERAHIST COUGH SYRUP' 67='(67) KEFLEX'
                  68='(68) PROCARDIA' 69='(69) SINEQUIN' 70='(70) ISONIAZID' 71='(71) DOXEPIN'
                  72='(72) IMIPANINE' 73='(73) HYDROXYZINE' 74='(74) DISULFIRAM'
                  75='(75) AXID, ACID CONTROL MEDICINE' 76='(76) ZOLOFT' 77='(77) VICODIN'
                  78='(78) LORAZEPAN' 79='(79) PYRIDOXINE' 80='(80) TRIMAX' 81='(81) CEFZIL'
                  82='(82) GUIATUSS' 83='(83) PHENYLPROP' 84='(84) ALBUTEROL' 85='(85) BECONASE'
                  86='(86) DURATUSS' 87='(87) FLUORINONILE CREAM' 88='(88) GLYBURIDE'
                  89='(89) PSYCHOTROPIC MEDS' 90='(90) SOMA' 91='(91) VEETIDS' 92='(92) PLENDIL'
                  93='(93) HYDROCHOROTLIAZIDE' 94='(94) FELODIPINE'
                  95='(95) PSEUDOEPHEDRINE, SUDAFED' 96='(96) DIFLUCAN' 97='(97) RIFAMPIN'
                  98='(98) RETROVIR' 99='(99) ATORANQUINE' 100='(100) TOFRANIL'
                  101='(101) TRILAFON' 102='(102) DIZERYPERMIM' 103='(103) PRALASAC'
                  104='(104) ALACTONE' 105='(105) VITAMINS, OR A VITAMIN' 106='(106) ASPIRIN'
                  107='(107) IRON, FERROS SULFATE' 108='(108) CHLORDIAZEPOXIDE'
                  109='(109) MAALOX' 110='(110) PRENATAL VITAMINS' 111='(111) AMOXICILLIN'
                  112='(112) VOLTAREN' 113='(113) ERYTHROMYCEN' 114='(114) PROMETHAZINE'
                  115='(115) METRUNIDZOLE' 116='(116) ATENOLOL' 117='(117) ULTRAM'
                  118='(118) METFORMIN' 119='(119) INSULIN' 120='(120) BACTRACIN' 121='(121) FLAGYL'
                  122='(122) CIPROFLOXCIN' 123='(123) PHENEGAN'
                  124='(124) FERROUS SULFATE (USE 107)' 125='(125) LABRAMYCIN'
                  126='(126) TYLENOL WITH CODEINE, TYLENOL #3' 127='(127) HALDOL'
                  128='(128) BENEDRYL' 129='(129) CHLORTRIMETON' 130='(130) SMZ/TMD'
                  131='(131) EQUATE' 132='(132) SERZONE' 133='(133) NALDOCON' 134='(134) SURFAK'
                  135='(135) PROVENTIL INHALER/NEBULIZER' 136='(136) TORODAL'
                  137='(137) AMOXIL' 138='(138) METHYLPRED' 139='(139) ESKALITH'
                  140='(140) PHENOBARBITOL' 141='(141) WELLBUTRIN' 142='(142) REVIA'
                  143='(143) ANTIBIOTICS, NOT NAMED' 144='(144) MICRONASE'
                  145='(145) LOPRESSOR' 146='(146) BUSBON' 147='(147) ASTHMA INHALER/MEDICINES'
                  148='(148) GLYIZIDE (FOR DIABETICS)' 149='(149) AZT' 150='(150) RISPERDAL'
                  151='(151) BEROCCA' 152='(152) MYLANTA' 153='(153) TETRACYCLINE'
                  154='(154) ANTIPYRLBENZOCAINE' 155='(155) E-MYCIN' 156='(156) TRI-LEVLEN'
                  157='(157) TRIMETHOBENZAMIDE' 158='(158) PROPRAPH' 159='(159) PISCARDIA'
                  160='(160) THORAZINE' 161='(161) PREMARIN' 162='(162) FAMVIR'
                  163='(163) DESORIMETASONE' 164='(164) ANUSOL' 165='(165) SENNA'
                  166='(166) HYDROGEN PEROXIDE' 167='(167) BENZOYL PEROXIDE'
                  168='(168) TOLNAFLATE' 169='(169) LACHYDRIN OR LACHYDIA'
                  170='(170) HYDERZINE' 171='(171) EURAX CREAM' 172='(172) ATARAX' 173='(173) CIPRO'
                  174='(174) MYCFLEX CREAM (MYCELEX CREAM?)' 175='(175) TAGAMET'
                  176='(176) PAMELOR' 177='(177) NORTRIPTYLYN' 178='(178) OLANZAPINE'
                  179='(179) NALTRAVONE' 180='(180) NALTAXORE' 181='(181) SERTRALINE'
                  182='(182) HEART MEDICINE' 183='(183) BLOOD PRESSURE MEDICINE'
                  184='(184) MELLARIL' 185='(185) PROLIXIN' 186='(186) PROLIXIN DECANDATE'
                  187='(187) RITALIN' 188='(188) SUMUCIN (FOR ACNE)' 189='(189) ADDERALL'
                  190='(190) LITHOBID' 191='(191) CALAN RS' 192='(192) TRAYENE' 193='(193) ZOCORE'
                  194='(194) ANATOL' 195='(195) THYROID MEDICINE' 196='(196) ACCUDE' 197='(197) AMBU'
                  198='(198) ALDACTONE' 199='(199) INDEROL' 200='(200) HYDROCOO/APAP'
                  201='(201) DIAZEPAM' 202='(202) LORCET' 203='(203) TOCOZ' 204='(204) FULICUN'
                  205='(205) INDOCIN' 206='(206) GLUCATROL' 207='(207) FLEXERIL' 208='(208) THIAMINE'
                  209='(209) CARAFATE' 210='(210) BROMOCRIPTINE' 211='(211) ELAVIL'
                  212='(212) FUROSEMIDE' 213='(213) LUTENSIN' 214='(214) EMYACIN'
                  215='(215) PREDNISONE' 216='(216) SCHIZOPRENIA MEDS' 217='(217) THEODUR'
                  218='(218) PROVESTIL' 219='(219) CYNTROID' 220='(220) NPD HUMILIN'
                  221='(221) STODBID' 222='(222) RETIMO' 223='(223) VIDEX' 224='(224) FIORERAL'
                  225='(225) SYNTHROID' 226='(226) TB MEDS' 227='(227) MORPHINE'
                  228='(228) NICLOXACILLIN' 229='(229) COLACE' 230='(230) COMPAZIN'
                  231='(231) LOTRIMIN' 232='(232) PRONEUHL' 233='(233) PROVERTAD' 234='(234) INH'
                  235='(235) DAXIL' 236='(236) CLIMDAMYCIN' 237='(237) INIVASE' 238='(238) EPIRIE'
                  239='(239) SYNOLAR' 240='(240) AUGMENTIN' 241='(241) DAYPRO' 242='(242) ESTROGEN'
                  243='(243) ROBAXIN' 244='(244) BICILLIN' 245='(245) ROBITUSSIN' 246='(246) PITOCIN'
                  247='(247) FESOG' 248='(248) PNV' 249='(249) PROVERA' 250='(250) TRILPONT'
                  251='(251) PROPANDOL' 252='(252) AMPICILLIN' 253='(253) SLOHID' 254='(254) PEN UK'
                  255='(255) VASOTEX' 256='(256) AEROLBID' 257='(257) CARDIXEM' 258='(258) LITIBIA'
                  259='(259) SEREVENT' 260='(260) REMERON' 261='(261) BADOFEN' 262='(262) SUCRALFATE'
                  263='(263) NAAROSYN' 264='(264) REBAXIN' 265='(265) ATROVENT'
                  266='(266) DIANZAPINE' 267='(267) CUREX' 268='(268) FE SO4' 269='(269) NIFEDIPINE'
                  270='(270) ALKA SELTZER' 271='(271) NAPROXEN' 272='(272) SUPHEDRINE'
                  273='(273) DARVON' 274='(274) ZYPREXA' 275='(275) PRINCIPEN' 276='(276) BIAXIN'
                  277='(277) ATRIPALIN' 278='(278) PERCOCERT' 279='(279) RELATEN'
                  280='(280) MILK OF MAGNESIA' 281='(281) ZESTRIOL' 282='(282) VALPROIC'
                  283='(283) REZULIN' 284='(284) CARDIZEN' 285='(285) AIPRAZOLAM'
                  286='(286) DIFLUCON' 287='(287) ACYCLOVIN' 288='(288) SELSUM LOTION'
                  289='(289) CEPHALEXIN' 290='(290) TRIAMICINOLONE' 291='(291) FLUVOYAMINE'
                  292='(292) DIVALPROEX' 293='(293) ENTEX' 294='(294) BACTRIM D.S'
                  295='(295) NICARDIPINE' 296='(296) VERAPAMIL' 297='(297) NOVOLIN'
                  298='(298) TRIVIL' 299='(299) BUTHEONTROL PILLS' 300='(300) PREVACID'
                  301='(301) IMURAN' 302='(302) CEFTIN' 303='(303) PHENYTOIN' 304='(304) FLUOXETINE'
                  305='(305) PECID AC' 306='(306) HABOPERIDOL' 307='(307) BENZTROPINE'
                  308='(308) THIOTHIZENE' 309='(309) CERENTIL' 310='(310) PRITOXEC'
                  311='(311) SULFANETHOXZOLE' 312='(312) SYMMETREL' 313='(313) ACETAMINOPHEN'
                  314='(314) PROPULSID' 315='(315) CLOZARIL' 316='(316) TRITEC' 317='(317) ISPERDONE'
                  318='(318) VICODRID' 319='(319) KOZOR' 320='(320) NELFINAVIE' 321='(321) CLARODENE'
                  322='(322) TEGIOXAL' 323='(323) AZITHROMYEIN' 324='(324) NORTRIPTICINE'
                  325='(325) FERNOSEMIDE' 326='(326) ALPRAZOLAM' 327='(327) ROXICET'
                  328='(328) LISINOPRIL' 329='(329) CHLORDIAZOPOXIDE' 330='(330) DENCILLIN'
                  331='(331) NASAL SPRAY' 332='(332) DIMIPRAMINE' 333='(333) FLENEMIL'
                  334='(334) HODINE XL' 335='(335) ACUPRIL' 336='(336) HOZOL' 337='(337) DUIRETIC'
                  338='(338) DIMOXICYLEN' 339='(339) QUEMAPRIL HCL ACCUPRIL'
                  340='(340) DALMANE' 341='(341) DELTASONE' 342='(342) HYDROXYCLORS'
                  343='(343) HALCION' 344='(344) HYDRECED' 345='(345) PRILOSEE'
                  346='(346) GLYBURIDEHOZOL' 347='(347) PONDIMIN' 348='(348) IONAMIN'
                  349='(349) BECLOVENT' 350='(350) CILYBURIDE' 351='(351) NYQUIL'
                  352='(352) DYSTHYMIA' 353='(353) ALLOPUINO' 354='(354) SERAZ' 355='(355) ATTAVAT'
                  356='(356) NITROGLYCERIN' 357='(357) RYTHMEL' 358='(358) PROCANAMIDE'
                  359='(359) REGLAN' 360='(360) CYCLOBENZAPRIN' 361='(361) CHLORPROMAZINE'
                  362='(362) KEMADRINE' 363='(363) FLURBIPROFIN' 364='(364) DIDIFENAC'
                  365='(365) IRI-CHROMALSANE' 366='(366) METOROLOL TARTRATE'
                  367='(367) DUCOSOTE' 368='(368) ROXIPRIN' 369='(369) DICLOXACILLIN'
                  370='(370) POTASSIUM' 371='(371) SUDAFED' 372='(372) IRIAZLSLEM'
                  373='(373) LOESTRINE' 374='(374) COUMODIN' 375='(375) VENTYLIN'
                  376='(376) DOCUISCITE' 377='(377) ZYPRIZA' 378='(378) UNISOM' 379='(379) ALEVE'
                  380='(380) MYSOLENE' 381='(381) PEGRATOL' 382='(382) AMOC/CLORAL/AUGMERTIA'
                  383='(383) LASIX' 384='(384) MONOPRIL' 385='(385) BACTRIA' 386='(386) AUGMENTIA'
                  387='(387) ASA' 388='(388) ALPROZOLAM' 389='(389) METRO CARBROL'
                  390='(390) ORUVAIL' 391='(391) PRILOSRC' 392='(392) LOXITANE' 393='(393) ZYPROXIN'
                  394='(394) BERPLEX PLUS' 395='(395) KETOPROFEN' 396='(396) LOPERAMIDE'
                  397='(397) VERTIDO' 398='(398) BRONCLODILATOR' 399='(399) CEFTER'
                  400='(400) HABITROL PATCH' 401='(401) CAPTOPRIL' 402='(402) PREPHENAZINE'
                  403='(403) NAXIDE' 404='(404) CLONAZEPAM' 405='(405) ZANAX' 406='(406) DEREYL'
                  407='(407) ZINEGUAN' 408='(408) DIFLUM' 409='(409) DAPCN' 410='(410) BACTRUM'
                  411='(411) TEGAMET' 412='(412) LIORASIL' 413='(413) NEFAZODONE'
                  414='(414) CONGISTAID' 415='(415) NALTREXONE' 416='(416) LEVOGUIN'
                  417='(417) GLIPIZID' 418='(418) SELDANE' 419='(419) LUVOX' 420='(420) ADALACK'
                  421='(421) PAXIN' 422='(422) CAPRICE III' 423='(423) LODENE' 424='(424) PERCOCET'
                  425='(425) CILIQUAN' 426='(426) SONBIEN' 427='(427) LICOZ' 428='(428) PEPAD'
                  429='(429) HYDROCODONE' 430='(430) VALPORIC ACID' 431='(431) PVK'
                  432='(432) FIOSOCAT' 433='(433) PROPOXY-NAPAP' 434='(434) DEBROX'
                  435='(435) MIDRIN' 436='(436) MICONAZOLE' 437='(437) ROSPERIDONE'
                  438='(438) PROPRANOLOL' 439='(439) HIZONE' 440='(440) PREMADEN'
                  441='(441) KLONIDINE' 442='(442) LEVOTHYROXINE SODIUM'
                  443='(443) PHENCIZOPYRDINE' 444='(444) TRUPROFEN' 445='(445) FOLATE'
                  446='(446) PAN VA' 447='(447) DIPHENOXYLATE' 448='(448) NICOTINE REFREM'
                  449='(449) TIAC' 450='(450) HZMACORT' 451='(451) NAPRALAN' 452='(452) TEMAXIPAN'
                  453='(453) RIFADIN' 454='(454) ZYRTEX' 455='(455) MEVACOR' 456='(456) VIFLEX'
                  457='(457) COMPAZINE' 458='(458) HCTZ' 459='(459) K-LYTE' 460='(460) DIABETA'
                  461='(461) ACIFED' 462='(462) CLORIDINE' 463='(463) PYRIMETHAMINE'
                  464='(464) SLEEPING PILLS' 465='(465) CAPTAPRIL' 466='(466) TIMOLOLMALEATG'
                  467='(467) CIMETIDINE' 468='(468) TRYSOPT' 469='(469) HYDROCORTISONE'
                  470='(470) METHEGRINE' 471='(471) TERAZOL' 472='(472) CLIOCIN VAGINAL CREAM'
                  473='(473) COMBIVER' 474='(474) PHERONOL' 475='(475) ULTRAVALT CREAM'
                  476='(476) LISINOGNIL' 477='(477) OXYCANTIN' 478='(478) CRIXIVCEN' 479='(479) TBID'
                  480='(480) VERCERIL' 481='(481) DILTEAZEN' 482='(482) DEXAMETHASON'
                  483='(483) NICITROL' 484='(484) DESOROL' 485='(485) FIORPAP' 486='(486) D3I'
                  487='(487) STAVODINE' 488='(488) PROCARDIN' 489='(489) STELAZINE'
                  490='(490) ZALATAN' 491='(491) VANCENASE' 492='(492) BUTRIN' 493='(493) ESSEVOR'
                  494='(494) MATAIN' 495='(495) NICODERM PATCH' 496='(496) PERCOCOET'
                  497='(497) SANDOGLOBULIN INFUSION' 498='(498) MSAID' 499='(499) DONNATAL'
                  500='(500) TRESIDONE' 501='(501) PREMETHOZINE' 502='(502) CODAMINE SYRUP'
                  503='(503) FLAPHENOZINE' 504='(504) CUMIDIN' 505='(505) HYTRIN'
                  506='(506) POLOMAINE' 507='(507) TINANCIN' 508='(508) DIOVAN' 509='(509) IBU'
                  510='(510) TROPOMINE' 511='(511) LANOXIN' 512='(512) AMITRIPTY'
                  513='(513) ALPRAZALAN' 514='(514) KERLON' ;
  VALUE a68a3fff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) AMBIEN' 2='(2) ANAPROX' 3='(3) BROMATAPP'
                  4='(4) BUSPER' 5='(5) CLARITIN D' 6='(6) CLONIDINE' 7='(7) CYLERT'
                  8='(8) DESYREL' 9='(9) DEPAKOTE' 10='(10) DOXYCYCLINE' 11='(11) EFFEXOR'
                  12='(12) EPIVIR' 13='(13) EYE DROPS' 14='(14) IBUPROFEN, ADVIL'
                  15='(15) KLONAPIN' 16='(16) LOMOTIL' 17='(17) MOTRIN' 18='(18) NAPROSYN, ALEVE'
                  19='(19) NORVASC' 20='(20) PAXIL' 21='(21) PENICILLIN, PEN VK' 22='(22) PROZAC'
                  23='(23) TRAZODONE' 24='(24) TRIMETHOPRIM' 25='(25) TUSSI'
                  26='(26) TYLENOL, ACETAMINOPHEN' 27='(27) VENTOLIN' 28='(28) ZERIT'
                  29='(29) GULAFED CAPS' 30='(30) KETLEX' 31='(31) DIPHENHYDRAMINE'
                  32='(32) AMITRIPTYLINE, ELAVIL' 33='(33) CARISOPRODOL' 34='(34) CODEINE'
                  35='(35) DILATIN' 36='(36) VALIUM' 37='(37) TEGRETOL' 38='(38) XANAX'
                  39='(39) DEMORAL' 40='(40) VISTAREL, VISTARIL, VISTORIL' 41='(41) TORADOL'
                  42='(42) ANTABUSE' 43='(43) EUCHOR' 44='(44) IMOPRAMINE' 45='(45) DEPOLATE'
                  46='(46) TROZODUC' 47='(47) DCYOHBO' 48='(48) PERCIDAN' 49='(49) DARVOCET'
                  50='(50) TYLOX' 51='(51) DESIPRAMINE' 52='(52) ZANTAC' 53='(53) BENTAL'
                  54='(54) LITHIUM' 55='(55) NAVANE' 56='(56) COGENTIN' 57='(57) LIBRIUM'
                  58='(58) ATIVAN' 59='(59) HUMULIN' 60='(60) TYLENOL 325' 61='(61) ZOVIRAX'
                  62='(62) CATAPRES PATCH' 63='(63) K-DUR' 64='(64) TENORNIN'
                  65='(65) MOTRIN (600)' 66='(66) THERAHIST COUGH SYRUP' 67='(67) KEFLEX'
                  68='(68) PROCARDIA' 69='(69) SINEQUIN' 70='(70) ISONIAZID' 71='(71) DOXEPIN'
                  72='(72) IMIPANINE' 73='(73) HYDROXYZINE' 74='(74) DISULFIRAM'
                  75='(75) AXID, ACID CONTROL MEDICINE' 76='(76) ZOLOFT' 77='(77) VICODIN'
                  78='(78) LORAZEPAN' 79='(79) PYRIDOXINE' 80='(80) TRIMAX' 81='(81) CEFZIL'
                  82='(82) GUIATUSS' 83='(83) PHENYLPROP' 84='(84) ALBUTEROL' 85='(85) BECONASE'
                  86='(86) DURATUSS' 87='(87) FLUORINONILE CREAM' 88='(88) GLYBURIDE'
                  89='(89) PSYCHOTROPIC MEDS' 90='(90) SOMA' 91='(91) VEETIDS' 92='(92) PLENDIL'
                  93='(93) HYDROCHOROTLIAZIDE' 94='(94) FELODIPINE'
                  95='(95) PSEUDOEPHEDRINE, SUDAFED' 96='(96) DIFLUCAN' 97='(97) RIFAMPIN'
                  98='(98) RETROVIR' 99='(99) ATORANQUINE' 100='(100) TOFRANIL'
                  101='(101) TRILAFON' 102='(102) DIZERYPERMIM' 103='(103) PRALASAC'
                  104='(104) ALACTONE' 105='(105) VITAMINS, OR A VITAMIN' 106='(106) ASPIRIN'
                  107='(107) IRON, FERROS SULFATE' 108='(108) CHLORDIAZEPOXIDE'
                  109='(109) MAALOX' 110='(110) PRENATAL VITAMINS' 111='(111) AMOXICILLIN'
                  112='(112) VOLTAREN' 113='(113) ERYTHROMYCEN' 114='(114) PROMETHAZINE'
                  115='(115) METRUNIDZOLE' 116='(116) ATENOLOL' 117='(117) ULTRAM'
                  118='(118) METFORMIN' 119='(119) INSULIN' 120='(120) BACTRACIN' 121='(121) FLAGYL'
                  122='(122) CIPROFLOXCIN' 123='(123) PHENEGAN'
                  124='(124) FERROUS SULFATE (USE 107)' 125='(125) LABRAMYCIN'
                  126='(126) TYLENOL WITH CODEINE, TYLENOL #3' 127='(127) HALDOL'
                  128='(128) BENEDRYL' 129='(129) CHLORTRIMETON' 130='(130) SMZ/TMD'
                  131='(131) EQUATE' 132='(132) SERZONE' 133='(133) NALDOCON' 134='(134) SURFAK'
                  135='(135) PROVENTIL INHALER/NEBULIZER' 136='(136) TORODAL'
                  137='(137) AMOXIL' 138='(138) METHYLPRED' 139='(139) ESKALITH'
                  140='(140) PHENOBARBITOL' 141='(141) WELLBUTRIN' 142='(142) REVIA'
                  143='(143) ANTIBIOTICS, NOT NAMED' 144='(144) MICRONASE'
                  145='(145) LOPRESSOR' 146='(146) BUSBON' 147='(147) ASTHMA INHALER/MEDICINES'
                  148='(148) GLYIZIDE (FOR DIABETICS)' 149='(149) AZT' 150='(150) RISPERDAL'
                  151='(151) BEROCCA' 152='(152) MYLANTA' 153='(153) TETRACYCLINE'
                  154='(154) ANTIPYRLBENZOCAINE' 155='(155) E-MYCIN' 156='(156) TRI-LEVLEN'
                  157='(157) TRIMETHOBENZAMIDE' 158='(158) PROPRAPH' 159='(159) PISCARDIA'
                  160='(160) THORAZINE' 161='(161) PREMARIN' 162='(162) FAMVIR'
                  163='(163) DESORIMETASONE' 164='(164) ANUSOL' 165='(165) SENNA'
                  166='(166) HYDROGEN PEROXIDE' 167='(167) BENZOYL PEROXIDE'
                  168='(168) TOLNAFLATE' 169='(169) LACHYDRIN OR LACHYDIA'
                  170='(170) HYDERZINE' 171='(171) EURAX CREAM' 172='(172) ATARAX' 173='(173) CIPRO'
                  174='(174) MYCFLEX CREAM (MYCELEX CREAM?)' 175='(175) TAGAMET'
                  176='(176) PAMELOR' 177='(177) NORTRIPTYLYN' 178='(178) OLANZAPINE'
                  179='(179) NALTRAVONE' 180='(180) NALTAXORE' 181='(181) SERTRALINE'
                  182='(182) HEART MEDICINE' 183='(183) BLOOD PRESSURE MEDICINE'
                  184='(184) MELLARIL' 185='(185) PROLIXIN' 186='(186) PROLIXIN DECANDATE'
                  187='(187) RITALIN' 188='(188) SUMUCIN (FOR ACNE)' 189='(189) ADDERALL'
                  190='(190) LITHOBID' 191='(191) CALAN RS' 192='(192) TRAYENE' 193='(193) ZOCORE'
                  194='(194) ANATOL' 195='(195) THYROID MEDICINE' 196='(196) ACCUDE' 197='(197) AMBU'
                  198='(198) ALDACTONE' 199='(199) INDEROL' 200='(200) HYDROCOO/APAP'
                  201='(201) DIAZEPAM' 202='(202) LORCET' 203='(203) TOCOZ' 204='(204) FULICUN'
                  205='(205) INDOCIN' 206='(206) GLUCATROL' 207='(207) FLEXERIL' 208='(208) THIAMINE'
                  209='(209) CARAFATE' 210='(210) BROMOCRIPTINE' 211='(211) ELAVIL'
                  212='(212) FUROSEMIDE' 213='(213) LUTENSIN' 214='(214) EMYACIN'
                  215='(215) PREDNISONE' 216='(216) SCHIZOPRENIA MEDS' 217='(217) THEODUR'
                  218='(218) PROVESTIL' 219='(219) CYNTROID' 220='(220) NPD HUMILIN'
                  221='(221) STODBID' 222='(222) RETIMO' 223='(223) VIDEX' 224='(224) FIORERAL'
                  225='(225) SYNTHROID' 226='(226) TB MEDS' 227='(227) MORPHINE'
                  228='(228) NICLOXACILLIN' 229='(229) COLACE' 230='(230) COMPAZIN'
                  231='(231) LOTRIMIN' 232='(232) PRONEUHL' 233='(233) PROVERTAD' 234='(234) INH'
                  235='(235) DAXIL' 236='(236) CLIMDAMYCIN' 237='(237) INIVASE' 238='(238) EPIRIE'
                  239='(239) SYNOLAR' 240='(240) AUGMENTIN' 241='(241) DAYPRO' 242='(242) ESTROGEN'
                  243='(243) ROBAXIN' 244='(244) BICILLIN' 245='(245) ROBITUSSIN' 246='(246) PITOCIN'
                  247='(247) FESOG' 248='(248) PNV' 249='(249) PROVERA' 250='(250) TRILPONT'
                  251='(251) PROPANDOL' 252='(252) AMPICILLIN' 253='(253) SLOHID' 254='(254) PEN UK'
                  255='(255) VASOTEX' 256='(256) AEROLBID' 257='(257) CARDIXEM' 258='(258) LITIBIA'
                  259='(259) SEREVENT' 260='(260) REMERON' 261='(261) BADOFEN' 262='(262) SUCRALFATE'
                  263='(263) NAAROSYN' 264='(264) REBAXIN' 265='(265) ATROVENT'
                  266='(266) DIANZAPINE' 267='(267) CUREX' 268='(268) FE SO4' 269='(269) NIFEDIPINE'
                  270='(270) ALKA SELTZER' 271='(271) NAPROXEN' 272='(272) SUPHEDRINE'
                  273='(273) DARVON' 274='(274) ZYPREXA' 275='(275) PRINCIPEN' 276='(276) BIAXIN'
                  277='(277) ATRIPALIN' 278='(278) PERCOCERT' 279='(279) RELATEN'
                  280='(280) MILK OF MAGNESIA' 281='(281) ZESTRIOL' 282='(282) VALPROIC'
                  283='(283) REZULIN' 284='(284) CARDIZEN' 285='(285) AIPRAZOLAM'
                  286='(286) DIFLUCON' 287='(287) ACYCLOVIN' 288='(288) SELSUM LOTION'
                  289='(289) CEPHALEXIN' 290='(290) TRIAMICINOLONE' 291='(291) FLUVOYAMINE'
                  292='(292) DIVALPROEX' 293='(293) ENTEX' 294='(294) BACTRIM D.S'
                  295='(295) NICARDIPINE' 296='(296) VERAPAMIL' 297='(297) NOVOLIN'
                  298='(298) TRIVIL' 299='(299) BUTHEONTROL PILLS' 300='(300) PREVACID'
                  301='(301) IMURAN' 302='(302) CEFTIN' 303='(303) PHENYTOIN' 304='(304) FLUOXETINE'
                  305='(305) PECID AC' 306='(306) HABOPERIDOL' 307='(307) BENZTROPINE'
                  308='(308) THIOTHIZENE' 309='(309) CERENTIL' 310='(310) PRITOXEC'
                  311='(311) SULFANETHOXZOLE' 312='(312) SYMMETREL' 313='(313) ACETAMINOPHEN'
                  314='(314) PROPULSID' 315='(315) CLOZARIL' 316='(316) TRITEC' 317='(317) ISPERDONE'
                  318='(318) VICODRID' 319='(319) KOZOR' 320='(320) NELFINAVIE' 321='(321) CLARODENE'
                  322='(322) TEGIOXAL' 323='(323) AZITHROMYEIN' 324='(324) NORTRIPTICINE'
                  325='(325) FERNOSEMIDE' 326='(326) ALPRAZOLAM' 327='(327) ROXICET'
                  328='(328) LISINOPRIL' 329='(329) CHLORDIAZOPOXIDE' 330='(330) DENCILLIN'
                  331='(331) NASAL SPRAY' 332='(332) DIMIPRAMINE' 333='(333) FLENEMIL'
                  334='(334) HODINE XL' 335='(335) ACUPRIL' 336='(336) HOZOL' 337='(337) DUIRETIC'
                  338='(338) DIMOXICYLEN' 339='(339) QUEMAPRIL HCL ACCUPRIL'
                  340='(340) DALMANE' 341='(341) DELTASONE' 342='(342) HYDROXYCLORS'
                  343='(343) HALCION' 344='(344) HYDRECED' 345='(345) PRILOSEE'
                  346='(346) GLYBURIDEHOZOL' 347='(347) PONDIMIN' 348='(348) IONAMIN'
                  349='(349) BECLOVENT' 350='(350) CILYBURIDE' 351='(351) NYQUIL'
                  352='(352) DYSTHYMIA' 353='(353) ALLOPUINO' 354='(354) SERAZ' 355='(355) ATTAVAT'
                  356='(356) NITROGLYCERIN' 357='(357) RYTHMEL' 358='(358) PROCANAMIDE'
                  359='(359) REGLAN' 360='(360) CYCLOBENZAPRIN' 361='(361) CHLORPROMAZINE'
                  362='(362) KEMADRINE' 363='(363) FLURBIPROFIN' 364='(364) DIDIFENAC'
                  365='(365) IRI-CHROMALSANE' 366='(366) METOROLOL TARTRATE'
                  367='(367) DUCOSOTE' 368='(368) ROXIPRIN' 369='(369) DICLOXACILLIN'
                  370='(370) POTASSIUM' 371='(371) SUDAFED' 372='(372) IRIAZLSLEM'
                  373='(373) LOESTRINE' 374='(374) COUMODIN' 375='(375) VENTYLIN'
                  376='(376) DOCUISCITE' 377='(377) ZYPRIZA' 378='(378) UNISOM' 379='(379) ALEVE'
                  380='(380) MYSOLENE' 381='(381) PEGRATOL' 382='(382) AMOC/CLORAL/AUGMERTIA'
                  383='(383) LASIX' 384='(384) MONOPRIL' 385='(385) BACTRIA' 386='(386) AUGMENTIA'
                  387='(387) ASA' 388='(388) ALPROZOLAM' 389='(389) METRO CARBROL'
                  390='(390) ORUVAIL' 391='(391) PRILOSRC' 392='(392) LOXITANE' 393='(393) ZYPROXIN'
                  394='(394) BERPLEX PLUS' 395='(395) KETOPROFEN' 396='(396) LOPERAMIDE'
                  397='(397) VERTIDO' 398='(398) BRONCLODILATOR' 399='(399) CEFTER'
                  400='(400) HABITROL PATCH' 401='(401) CAPTOPRIL' 402='(402) PREPHENAZINE'
                  403='(403) NAXIDE' 404='(404) CLONAZEPAM' 405='(405) ZANAX' 406='(406) DEREYL'
                  407='(407) ZINEGUAN' 408='(408) DIFLUM' 409='(409) DAPCN' 410='(410) BACTRUM'
                  411='(411) TEGAMET' 412='(412) LIORASIL' 413='(413) NEFAZODONE'
                  414='(414) CONGISTAID' 415='(415) NALTREXONE' 416='(416) LEVOGUIN'
                  417='(417) GLIPIZID' 418='(418) SELDANE' 419='(419) LUVOX' 420='(420) ADALACK'
                  421='(421) PAXIN' 422='(422) CAPRICE III' 423='(423) LODENE' 424='(424) PERCOCET'
                  425='(425) CILIQUAN' 426='(426) SONBIEN' 427='(427) LICOZ' 428='(428) PEPAD'
                  429='(429) HYDROCODONE' 430='(430) VALPORIC ACID' 431='(431) PVK'
                  432='(432) FIOSOCAT' 433='(433) PROPOXY-NAPAP' 434='(434) DEBROX'
                  435='(435) MIDRIN' 436='(436) MICONAZOLE' 437='(437) ROSPERIDONE'
                  438='(438) PROPRANOLOL' 439='(439) HIZONE' 440='(440) PREMADEN'
                  441='(441) KLONIDINE' 442='(442) LEVOTHYROXINE SODIUM'
                  443='(443) PHENCIZOPYRDINE' 444='(444) TRUPROFEN' 445='(445) FOLATE'
                  446='(446) PAN VA' 447='(447) DIPHENOXYLATE' 448='(448) NICOTINE REFREM'
                  449='(449) TIAC' 450='(450) HZMACORT' 451='(451) NAPRALAN' 452='(452) TEMAXIPAN'
                  453='(453) RIFADIN' 454='(454) ZYRTEX' 455='(455) MEVACOR' 456='(456) VIFLEX'
                  457='(457) COMPAZINE' 458='(458) HCTZ' 459='(459) K-LYTE' 460='(460) DIABETA'
                  461='(461) ACIFED' 462='(462) CLORIDINE' 463='(463) PYRIMETHAMINE'
                  464='(464) SLEEPING PILLS' 465='(465) CAPTAPRIL' 466='(466) TIMOLOLMALEATG'
                  467='(467) CIMETIDINE' 468='(468) TRYSOPT' 469='(469) HYDROCORTISONE'
                  470='(470) METHEGRINE' 471='(471) TERAZOL' 472='(472) CLIOCIN VAGINAL CREAM'
                  473='(473) COMBIVER' 474='(474) PHERONOL' 475='(475) ULTRAVALT CREAM'
                  476='(476) LISINOGNIL' 477='(477) OXYCANTIN' 478='(478) CRIXIVCEN' 479='(479) TBID'
                  480='(480) VERCERIL' 481='(481) DILTEAZEN' 482='(482) DEXAMETHASON'
                  483='(483) NICITROL' 484='(484) DESOROL' 485='(485) FIORPAP' 486='(486) D3I'
                  487='(487) STAVODINE' 488='(488) PROCARDIN' 489='(489) STELAZINE'
                  490='(490) ZALATAN' 491='(491) VANCENASE' 492='(492) BUTRIN' 493='(493) ESSEVOR'
                  494='(494) MATAIN' 495='(495) NICODERM PATCH' 496='(496) PERCOCOET'
                  497='(497) SANDOGLOBULIN INFUSION' 498='(498) MSAID' 499='(499) DONNATAL'
                  500='(500) TRESIDONE' 501='(501) PREMETHOZINE' 502='(502) CODAMINE SYRUP'
                  503='(503) FLAPHENOZINE' 504='(504) CUMIDIN' 505='(505) HYTRIN'
                  506='(506) POLOMAINE' 507='(507) TINANCIN' 508='(508) DIOVAN' 509='(509) IBU'
                  510='(510) TROPOMINE' 511='(511) LANOXIN' 512='(512) AMITRIPTY'
                  513='(513) ALPRAZALAN' 514='(514) KERLON' ;
  VALUE a69fffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 0='(0) NO' 1='(1) YES' ;
  VALUE a69btd    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE a69ctd    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE a69dtd    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE a70fffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 0='(0) NO' 1='(1) YES' ;
  VALUE a73fffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 0='(0) CLIENT DECEASED'
                  1='(1) COMPLETED PLANNED TREATMENT'
                  2='(2) DIDN''T COMPLETE TX, REFERRED/TRANSFERRED'
                  3='(3) DIDN''T COMPLETE TX, INSURANCE BENEFITS E'
                  4='(4) DIDN''T COMPLETE TX, NO PAYMENT SOURCE'
                  5='(5) DIDN''T COMPLETE TX BY ADMINISTRATION CHO'
                  6='(6) DIDN''T COMPLETE TX BY CLIENT CHOICE'
                  7='(7) DIDN''T COMPLETE TX, INCARCERATED'
                  8='(8) DIDN''T COMPLETE TX, NOT OTHERWISE SPECIF'
                  9='(9) PENDING COMPLETION OF ASSIGNMENT'
                  10='(10) MUTUAL AGREEMENT TO TERMINATE'
                  11='(11) LAWYER TERMINATED THERAPY, COURT TERMINA'
                  12='(12) TREATMENT NEVER STARTED'
                  13='(13) PROBLEMS WITH TRANSPORTATION' 14='(14) EVALUATION ONLY'
                  15='(15) ARRESTED' 16='(16) MOVED AWAY'
                  17='(17) DROP OUT, PHYSICAL ILLNESS (E.G.,CANCER)'
                  18='(18) REFERRED TO NON-SA TREATMENT'
                  19='(19) MEDICALLY DISCHARGE AFTERCARE' 20='(20) HAVING A BABY' ;
  VALUE a74cn     -9='(-9) INAP CLIENT TYPE IS METH/IN-TX METH CLIE' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW'
                  0='(0) NO DIAGNOSIS SPECIFIED' 1='(1) ONE DIAGNOSIS SPECIFIED'
                  2='(2) TWO DIAGNOSES SPECIFIED' 3='(3) THREE DIAGNOSES SPECIFIED'
                  4='(4) FOUR DIAGNOSES SPECIFIED' 5='(5) FIVE DIAGNOSES SPECIFIED'
                  6='(6) SIX DIAGNOSES SPECIFIED' 7='(7) SEVEN DIAGNOSES SPECIFIED'
                  8='(8) EIGHT DIAGNOSES SPECIFIED' ;
  VALUE a74a      -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -7='(-7) NOT ASCERTAINED'
                  -5='(-5) MISSING' 0='(0) NO DIAGNOSIS' 1='(1) ALCOHOL-INDUCED DISORDER'
                  2='(2) SUBSTANCE-INDUCED DISORDER' 3='(3) ALCOHOL INTOXICATION'
                  4='(4) ALCOHOL DEPENDENCE' 5='(5) OPIOID DEPENDENCE'
                  6='(6) COCAINE DEPENDENCE' 7='(7) CANNABIS DEPENDENCE'
                  8='(8) OTHER SUBSTANCE DEPENDENCE' 9='(9) ALCOHOL ABUSE'
                  10='(10) CANNABIS ABUSE' 11='(11) OTH SUBST ABUSE' 12='(12) OPIOID ABUSE'
                  13='(13) COCAINE ABUSE' 14='(14) ANXIETY DISORDERS'
                  15='(15) DEPRESSIVE DISORDERS'
                  16='(16) SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS'
                  17='(17) BIPOLAR DISORDERS'
                  18='(18) ATTENTION DEFICIT/DISRUPTIVE BEH. DISORD'
                  19='(19) OTHER MENTAL HEALTH CONDITION' 20='(20) OTHER CONDITION' ;
  VALUE a74b      -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -7='(-7) NOT ASCERTAINED'
                  -5='(-5) MISSING' 0='(0) NO DIAGNOSIS' 1='(1) ALCOHOL-INDUCED DISORDER'
                  2='(2) SUBSTANCE-INDUCED DISORDER' 3='(3) ALCOHOL INTOXICATION'
                  4='(4) ALCOHOL DEPENDENCE' 5='(5) OPIOID DEPENDENCE'
                  6='(6) COCAINE DEPENDENCE' 7='(7) CANNABIS DEPENDENCE'
                  8='(8) OTHER SUBSTANCE DEPENDENCE' 9='(9) ALCOHOL ABUSE'
                  10='(10) CANNABIS ABUSE' 11='(11) OTH SUBST ABUSE' 12='(12) OPIOID ABUSE'
                  13='(13) COCAINE ABUSE' 14='(14) ANXIETY DISORDERS'
                  15='(15) DEPRESSIVE DISORDERS'
                  16='(16) SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS'
                  17='(17) BIPOLAR DISORDERS'
                  18='(18) ATTENTION DEFICIT/DISRUPTIVE BEH. DISORD'
                  19='(19) OTHER MENTAL HEALTH CONDITION' 20='(20) OTHER CONDITION' ;
  VALUE a74c      -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -7='(-7) NOT ASCERTAINED'
                  -5='(-5) MISSING' 0='(0) NO DIAGNOSIS' 1='(1) ALCOHOL-INDUCED DISORDER'
                  2='(2) SUBSTANCE-INDUCED DISORDER' 3='(3) ALCOHOL INTOXICATION'
                  4='(4) ALCOHOL DEPENDENCE' 5='(5) OPIOID DEPENDENCE'
                  6='(6) COCAINE DEPENDENCE' 7='(7) CANNABIS DEPENDENCE'
                  8='(8) OTHER SUBSTANCE DEPENDENCE' 9='(9) ALCOHOL ABUSE'
                  10='(10) CANNABIS ABUSE' 11='(11) OTH SUBST ABUSE' 12='(12) OPIOID ABUSE'
                  13='(13) COCAINE ABUSE' 14='(14) ANXIETY DISORDERS'
                  15='(15) DEPRESSIVE DISORDERS'
                  16='(16) SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS'
                  17='(17) BIPOLAR DISORDERS'
                  18='(18) ATTENTION DEFICIT/DISRUPTIVE BEH. DISORD'
                  19='(19) OTHER MENTAL HEALTH CONDITION' 20='(20) OTHER CONDITION' ;
  VALUE a74d      -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -7='(-7) NOT ASCERTAINED'
                  -5='(-5) MISSING' 0='(0) NO DIAGNOSIS' 1='(1) ALCOHOL-INDUCED DISORDER'
                  2='(2) SUBSTANCE-INDUCED DISORDER' 3='(3) ALCOHOL INTOXICATION'
                  4='(4) ALCOHOL DEPENDENCE' 5='(5) OPIOID DEPENDENCE'
                  6='(6) COCAINE DEPENDENCE' 7='(7) CANNABIS DEPENDENCE'
                  8='(8) OTHER SUBSTANCE DEPENDENCE' 9='(9) ALCOHOL ABUSE'
                  10='(10) CANNABIS ABUSE' 11='(11) OTH SUBST ABUSE' 12='(12) OPIOID ABUSE'
                  13='(13) COCAINE ABUSE' 14='(14) ANXIETY DISORDERS'
                  15='(15) DEPRESSIVE DISORDERS'
                  16='(16) SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS'
                  17='(17) BIPOLAR DISORDERS'
                  18='(18) ATTENTION DEFICIT/DISRUPTIVE BEH. DISORD'
                  19='(19) OTHER MENTAL HEALTH CONDITION' 20='(20) OTHER CONDITION' ;
  VALUE a74e      -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -7='(-7) NOT ASCERTAINED'
                  -5='(-5) MISSING' 0='(0) NO DIAGNOSIS' 1='(1) ALCOHOL-INDUCED DISORDER'
                  2='(2) SUBSTANCE-INDUCED DISORDER' 3='(3) ALCOHOL INTOXICATION'
                  4='(4) ALCOHOL DEPENDENCE' 5='(5) OPIOID DEPENDENCE'
                  6='(6) COCAINE DEPENDENCE' 7='(7) CANNABIS DEPENDENCE'
                  8='(8) OTHER SUBSTANCE DEPENDENCE' 9='(9) ALCOHOL ABUSE'
                  10='(10) CANNABIS ABUSE' 11='(11) OTH SUBST ABUSE' 12='(12) OPIOID ABUSE'
                  13='(13) COCAINE ABUSE' 14='(14) ANXIETY DISORDERS'
                  15='(15) DEPRESSIVE DISORDERS'
                  16='(16) SCHIZOPHRENIA/OTHER PSYCHOTIC DISORDERS'
                  17='(17) BIPOLAR DISORDERS'
                  18='(18) ATTENTION DEFICIT/DISRUPTIVE BEH. DISORD'
                  19='(19) OTHER MENTAL HEALTH CONDITION' 20='(20) OTHER CONDITION' ;
  VALUE a75fffff  -9='(-9) INAP CLIENT TYPE METH DIS OR IN-TX METH' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO'
                  1='(1) YES, SPECIFY MENTAL ILLNESS BELOW'
                  2='(2) YES, BUT ILLNESS NOT SPECIFIED' ;
  VALUE a75a      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) BI-POLAR AND DEPRESSION'
                  2='(2) DEPRESSION AND ANXIETY'
                  3='(3) MAJOR DEPRESSIVE DISORDER RECURRENT/MAJO'
                  4='(4) DEPRESSION, POSSIBLE DEPRESSION'
                  5='(5) PANIC DISORDER WITH AGRAPHOBIA' 6='(6) DEPRESSION/SUICIDAL'
                  7='(7) BI-POLAR I, II, OR PLAIN'
                  8='(8) CUNABAIS DEPENDENCE STABALIZE MOOD'
                  9='(9) IMPULSIVE BEHAVIOR'
                  10='(10) ANIT-SOCIAL PERSONALITY DISORDER' 11='(11) BI-POLAR/MANIC'
                  12='(12) BI-POLAR/BORDERLINE PERSONALITY DISORD'
                  13='(13) AVOIDANT PERSONALITY DISORDER'
                  14='(14) MAJOR DEPRESSION/DEPENDENT PERSONALITY D'
                  15='(15) ADJUSTMENT DISORDER/PERSONALITY DISORDER'
                  16='(16) ANXIETY DISORDER' 17='(17) ADJUSTMENT DISORDER'
                  18='(18) SCHIZOAFFECTIVE, SHIZOPHRENIA' 19='(19) PARANOIA'
                  20='(20) MULTIPLE PERSONALITY DISORDER OR POSSIBL'
                  21='(21) SCHIZOPHRENIA AND BI-POLAR'
                  22='(22) ADJUSTMENT DISORDER/DEPRESSION' 23='(23) DOMESTIC ABUSE'
                  24='(24) SEXUAL ADDICTION' 25='(25) PSYCHOTIC DISORDER'
                  26='(26) PSYCHIATRIC COMPLICATIONS' 27='(27) PSYCHO-SOCIAL PROBLEMS'
                  28='(28) DEPRESSION AND PANIC DISORDER'
                  29='(29) POST TRAUMATIC STRESS DISORDER' 30='(30) DYSTHYMIA DISORDER'
                  31='(31) COGNITIVE DEFICITS' 32='(32) DUAL DIAGNOSIS'
                  33='(33) PASSIVE AGGRESSIVE PERSONALITY DISORDER'
                  34='(34) HALLUCINATIONS' 35='(35) SUICIDAL' 36='(36) ANGER'
                  88='(88) MANY PROBLEMS LISTED' ;
  VALUE a76fffff  -9='(-9) INAPP CLIENT TYPE IS METH OR IN-TX METH' -8='(-8) REFUSED'
                  -7='(-7) UNABLE TO DETERMINE' -6='(-6) DON''T KNOW' 0='(0) NO' 1='(1) YES' ;
  VALUE a77fffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) SERVICES SPECIFIED' ;
  VALUE a77a      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 0='(0) NO' 1='(1) YES' ;
  VALUE a77b      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 0='(0) NO' 1='(1) YES' ;
  VALUE a77c      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 0='(0) NO' 1='(1) YES' ;
  VALUE a77d      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 0='(0) NO' 1='(1) YES' ;
  VALUE a77e      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 0='(0) NO' 1='(1) YES' ;
  VALUE a77f      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 0='(0) NO' 1='(1) YES' ;
  VALUE a77g      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 0='(0) NO' 1='(1) YES' ;
  VALUE a78fffff  -9='(-9) INAP CLIENT TYPE IS METH/IN-TX METH CLIE' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO TREATMENT'
                  1='(1) HOSPITAL INPATIENT' 2='(2) RESIDENTIAL'
                  3='(3) OUTPATIENT METHADONE' 4='(4) OUTPATIENT NON-METHADONE'
                  5='(5) SUBSTANCE ABUSE TREATMENT, NOT OTHERWISE'
                  8='(8) OTHER, SPECIFY' ;
  VALUE a79fffff  -9='(-9) INAP CLIENT TYPE IS METH OR IN-TX METH C' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE a79u      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) DAYS' 2='(2) WEEKS' 3='(3) MONTHS' 4='(4) YEARS'
                  5='(5) VISITS' 6='(6) HOURS' ;
  VALUE a79a      -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) MANAGED CARE PLAN'
                  2='(2) OTHER THIRD PARTY PAYER' 3='(3) OTHER SPECIFIED' ;
  VALUE a80fffff  -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' ;
  VALUE a80b      -9='(-9) INAPPLICABLE, A80 NOT CODED 00000' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO' 1='(1) YES' ;
  VALUE a81fffff  -9='(-9) INAPPLICABLE, CLIENT TYPE CODED 2' -8='(-8) REFUSED'
                  -7='(-7) NOT ASCERTAINED' -6='(-6) DON''T KNOW' 0='(0) NO CHARGES'
                  1='(1) FULL AMOUNT BILLED' 2='(2) SLIDING FEE AMOUNT'
                  3='(3) REDUCED AMOUNT' 6='(6) NOT PERMITTED TO ABSTRACT' 8='(8) OTHER' ;
  VALUE a81pc     -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
  VALUE a82fffff  -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) YES, COMMENTS' 2='(2) NO COMMENTS RECORDED' ;
  VALUE a55oth    -9='(-9) INAPPLICBALE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) STEROIDS' 2='(2) POTASSIUM CITRATE'
                  3='(3) DEPAKOTE' 4='(4) PROZAC' 5='(5) PAIN PILLS'
                  6='(6) STEROID INJECTION (2) CCS' 7='(7) CHOLONODINE' 8='(8) TEGRETOL'
                  9='(9) LITHIUM' 10='(10) VERAPMIL' 11='(11) WELLBUTRIN'
                  12='(12) AMITRIPTYLINE, ELAVIL' 13='(13) LINSEL' 14='(14) FLEXERIL'
                  15='(15) POLYDRUG' 16='(16) ZOLOFT' 17='(17) BUSPAR' 18='(18) NALTREXONE'
                  19='(19) TRAZODONE' 20='(20) ZANTAC OR ZANTAX' 21='(21) PAXIL'
                  22='(22) LODIENE' 23='(23) ANXIOLYTICS' 24='(24) LANAX' 25='(25) SONA'
                  26='(26) ANAPROXEN' 27='(27) HYCEDAL' 28='(28) SOMA' 29='(29) ZIAC'
                  30='(30) SINEQUAN' 31='(31) FLORCET' 32='(32) THORAZINE' 33='(33) PREDNISONE'
                  34='(34) SERZONE' 35='(35) ELAVIL' 36='(36) NERVE DRUGS (PILLS)'
                  37='(37) ANTABUSE' 38='(38) PILLS' 39='(39) RISPERDAL' 40='(40) NAPROXIN'
                  41='(41) RX DRUGS' 42='(42) IBUPROFEN, MOTRIN' 43='(43) TRANQUILIZERS'
                  44='(44) HALDOL' 45='(45) DILANTIN' 46='(46) TRIFILIN' ;
  VALUE a56oth    -9='(-9) INAPPLICBALE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' 1='(1) STEROIDS' 2='(2) POTASSIUM CITRATE'
                  3='(3) DEPAKOTE' 4='(4) PROZAC' 5='(5) PAIN PILLS'
                  6='(6) STEROID INJECTION (2) CCS' 7='(7) CHOLONODINE' 8='(8) TEGRETOL'
                  9='(9) LITHIUM' 10='(10) VERAPMIL' 11='(11) WELLBUTRIN'
                  12='(12) AMITRIPTYLINE, ELAVIL' 13='(13) LINSEL' 14='(14) FLEXERIL'
                  15='(15) POLYDRUG' 16='(16) ZOLOFT' 17='(17) BUSPAR' 18='(18) NALTREXONE'
                  19='(19) TRAZODONE' 20='(20) ZANTAC OR ZANTAX' 21='(21) PAXIL'
                  22='(22) LODIENE' 23='(23) ANXIOLYTICS' 24='(24) LANAX' 25='(25) SONA'
                  26='(26) ANAPROXEN' 27='(27) HYCEDAL' 28='(28) SOMA' 29='(29) ZIAC'
                  30='(30) SINEQUAN' 31='(31) FLORCET' 32='(32) THORAZINE' 33='(33) PREDNISONE'
                  34='(34) SERZONE' 35='(35) ELAVIL' 36='(36) NERVE DRUGS (PILLS)'
                  37='(37) ANTABUSE' 38='(38) PILLS' 39='(39) RISPERDAL' 40='(40) NAPROXIN'
                  41='(41) RX DRUGS' 42='(42) IBUPROFEN, MOTRIN' 43='(43) TRANQUILIZERS'
                  44='(44) HALDOL' 45='(45) DILANTIN' 46='(46) TRIFILIN' ;
  VALUE age_calc  -5='(-5) MISSING' ;
  VALUE los       -5='(-5) MISSING' ;
  VALUE trt_dur   -5='(-5) Missing' ;
  VALUE alcohol   0='(0) ALCOHOL USE NOT MENTIONED IN CLIENT RECO'
                  1='(1) ALCOHOL USE MENTIONED IN CLIENT RECORD' ;
  VALUE drug      0='(0) DRUG USE NOT MENTIONED IN CLIENT RECORD'
                  1='(1) DRUG USE MENTIONED IN CLIENT RECORD' ;
  VALUE drug_alc  1='(1) ALCOHOL USE ONLY MENTIONED IN CLIENT REC'
                  2='(2) BOTH ALCOHOL AND DRUG USE MENTIONED IN C'
                  3='(3) DRUG USE ONLY MENTIONED IN CLIENT RECORD'
                  4='(4) UNSPEC SUB USE/NO MENTION OF WHICH SUB A' ;
  VALUE abssmpty  1='(1) E-EARLY DROPOUT' 2='(2) D-MAIN' 3='(3) I-IN TREATMENT METHADONE' ;
  VALUE qfstrat   2='(2) STRATUM 2 RESIDENTIAL'
                  3='(3) STRATUM 3 PREDOMINANTLY OUTPATIENT METHA'
                  4='(4) STRATUM 4 OP NON-METH-PREDOMINANTLY ALCO'
                  5='(5) STRATUM 5 OP NON-METH-NOT IN STRATUM 3 O'
                  6='(6) STRATUM 6 COMBINATION' ;
  VALUE group     0='(0) CLIENT TO RECEIVE $15/$10 FOR FOLLOWUP I'
                  1='(1) CLIENT TO RECEIVE $0/$0 FOR FOLLOWUP INT'
                  2='(2) CLIENT TO RECEIVE $0/$10 FOR FOLLOWUP IN'
                  3='(3) CLIENT TO RECEIVE $25/$10 FOR FOLLOWUP I' ;
  VALUE studyind  0='(0) INCENTIVE STUDY FACILITY' 1='(1) MAIN STUDY FACILITY' ;
  VALUE psutypef  1='(1) METRO CERTAINTY' 2='(2) METRO NONCERTAINTY'
                  3='(3) NONMETRO NONCERTAINTY' ;
  VALUE cenreg    1='(1) NORTHEAST' 2='(2) MIDWEST' 3='(3) SOUTH' 4='(4) WEST' ;
  VALUE own       -5='(-5) MISSING' 1='(1) PRIVATE FOR PROFIT' 2='(2) PRIVATE NONPROFIT'
                  3='(3) PUBLIC' ;
  VALUE factype   2='(2) FACILITY OFFERS RESIDENTIAL TREATMENT ON'
                  3='(3) FACILITY OFFERS OUTPATIENT METHADONE TRE'
                  4='(4) FACILITY OFFERS OUTPATIENT NON-METHADONE'
                  5='(5) FACILITY OFFERS MORE THAN ONE TYPE OF TR' ;
  VALUE txcare    1='(1) M-OUTPATIENT METHADONE' 2='(2) N-OUTPATIENT NON-METHADONE'
                  3='(3) R-NON-HOSPITAL RESIDENTIAL' ;
  VALUE a69atd    -9='(-9) INAPPLICABLE' -8='(-8) REFUSED' -7='(-7) NOT ASCERTAINED'
                  -6='(-6) DON''T KNOW' ;
*/


* SAS DATA, INFILE, INPUT STATEMENTS;

DATA;
INFILE "data-filename" LRECL=512;
INPUT
        CASEID 1-4              FACID 5-8               CLTYPE 9-10
        COMIN 11-13             A6 14-15                A6A1 16-17
        A6A2 18-19              A6A3 20-21              A7 22-23
        A9 24-25                A10 26-27               A11 28-29
        A14 30-31               A15 32-33               A16 34-35
        A17 36-37               A18 38-39               A19 40-41
        A20 42-43               A21 44-45               A22 46-47
        A23 48-49               A24 50-51               A25 52-53
        A26 54-55               A27 56-57               A28 58-59
        A29 60-61               A30A 62-63              A30B 64-65
        A30C 66-67              A30D 68-69              A30E 70-71
        A30F 72-73              A30G 74-75              A30H 76-77
        A30I 78-79              A30J 80-81              A31 82-83
        A32 84-85               A33A 86-87              A33B 88-89
        A33C 90-91              A33D 92-93              A33E 94-95
        A33F 96-97              A34 98-99               A35 100-101
        A36 102-103             A37 104-105             A38 106-107
        A39CN 108-109           A39A 110-111            A39B 112-113
        A39C 114-115            A39D 116-117            A39E 118-119
        A40EU 120-121           A40LU 122-123           A40AGE 124-125
        A41EU 126-127           A41LU 128-129           A41AGE 130-131
        A42EU 132-133           A42LU 134-135           A42AGE 136-137
        A43EU 138-139           A43LU 140-141           A43AGE 142-143
        A44EU 144-145           A44LU 146-147           A44AGE 148-149
        A45EU 150-151           A45LU 152-153           A45AGE 154-155
        A46EU 156-157           A46LU 158-159           A46AGE 160-161
        A47EU 162-163           A47LU 164-165           A47AGE 166-167
        A48EU 168-169           A48LU 170-171           A48AGE 172-173
        A49EU 174-175           A49LU 176-177           A49AGE 178-179
        A50EU 180-181           A50LU 182-183           A50AGE 184-185
        A51EU 186-187           A51LU 188-189           A51AGE 190-191
        A52EU 192-193           A52OTH 194-195          A52LU 196-197
        A52AGE 198-199          A53EU 200-201           A53LU 202-203
        A53AGE 204-205          A54EU 206-207           A54LU 208-209
        A54AGE 210-211          A55EU 212-213           A55LU 214-215
        A55AGE 216-217          A56EU 218-219           A56LU 220-221
        A56AGE 222-223          A57 224-225             A58A 226-227
        A58B 228-229            A58C 230-231            A59 232-233
        A60A 234-235            A60B 236-237            A60C 238-239
        A61 240-241             A62FOP 242-243          A62FCO 244-245
        A62FTHC 246-247         A62FOTH 248-249         A62LOP 250-251
        A62LCO 252-253          A62LTHC 254-255         A62LOTH 256-257
        A63 258-259             A64 260-261             A65 262-263
        A65AR 264-265           A65AF 266-267           A65AT 268-269
        A65AD 270-271           A65BR 272-273           A65BF 274-275
        A65BT 276-277           A65BD 278-279           A65CR 280-281
        A65CF 282-283           A65CT 284-285           A65CD 286-287
        A65DR 288-289           A65DF 290-291           A65DT 292-293
        A65DD 294-295           A65ER 296-297           A65EF 298-299
        A65ET 300-301           A65ED 302-303           A65FR 304-305
        A65FF 306-307           A65FT 308-309           A65FD 310-311
        A65GR 312-313           A65GF 314-315           A65GT 316-317
        A65GD 318-319           A65HR 320-321           A65HF 322-323
        A65HT 324-325           A65HD 326-327           A65IR 328-329
        A65IF 330-331           A65IT 332-333           A65ID 334-335
        A65JR 336-337           A65JF 338-339           A65JT 340-341
        A65JD 342-343           A66 344-345             A67A 346-347
        A67AN 348-349           A67B 350-351            A67BN 352-353
        A67C 354-355            A67CN 356-357           A67D 358-359
        A67DN 360-361           A67E 362-363            A67F 364-365
        A67G 366-367            A67H 368-369            A67I 370-371
        A67J 372-373            A67K 374-375            A67L 376-377
        A67M 378-379            A67N 380-381            A67O 382-383
        A67P 384-385            A67Q 386-387            A67R 388-389
        A67S 390-391            A67T 392-393            A68 394-395
        A68A1 396-398           A68A2 399-401           A68A3 402-404
        A69 405-406             A69BTD 407-408          A69CTD 409-410
        A69DTD 411-412          A70 413-414             A73 415-416
        A74CN 417-418           A74A 419-420            A74B 421-422
        A74C 423-424            A74D 425-426            A74E 427-428
        A75 429-430             A75A 431-432            A76 433-434
        A77 435-436             A77A 437-438            A77B 439-440
        A77C 441-442            A77D 443-444            A77E 445-446
        A77F 447-448            A77G 449-450            A78 451-452
        A79 453-454             A79U 455-456            A79A 457-458
        A80 459-461             A80B 462-463            A81 464-465
        A81PC 466-467           A82 468-469             A55OTH 470-471
        A56OTH 472-473          AGE_CALC 474-475        LOS 476-478
        TRT_DUR 479-480         ALCOHOL 481-482         DRUG 483-484
        DRUG_ALC 485-486        ABSSMPTY 487-488        QFSTRAT 489-490
        GROUP 491-492           STUDYIND 493-494        FIELDPSU 495-496
        PSUTYPE2 497-498        CENREG 499-500          OWN 501-502
        FACTYPE 503-504         TXCARE 505-506          VST_PSU 507-508
        VUN_PSU 509-510         A69ATD 511-512          ;


* SAS LABEL STATEMENT;

LABEL
   CASEID  = 'CLIENT CASE ID'
   FACID   = 'FACILITY CASE ID'
   CLTYPE  = 'CLIENT TYPE'
   COMIN   = 'TIME TO COMPLETE: IN MINUTES'
   A6      = 'A6. TYPE OF CARE FOR THIS DISCHARGE'
   A6A1    = 'A6A1. TRTMT RECEIVED: DETOXIFICATION'
   A6A2    = 'A6A2. TRTMT RECEIVED: REHABILITATION (DRUG-FREE)'
   A6A3    = 'A6A3. TRTMT RECEIVED: METHADONE'
   A7      = 'A7. CLIENT STAYED OVERNIGHT FOR THIS TRTMT'
   A9      = 'A9. PRIMARY SOURCE OF REFERRAL FOR TRTMT'
   A10     = 'A10. PRIMARY SOURCE OF PAYMENT FOR TRTMT'
   A11     = 'A11. IS CLIENT RECEIVING SSI BENEFITS'
   A14     = 'A14. SEX'
   A15     = 'A15. RACE'
   A16     = 'A16. ETHNICITY'
   A17     = 'A17. MARITAL STATUS AT ADMISSION'
   A18     = 'A18. HAVE CHILD/CHILDREN AT ADMISSION'
   A19     = 'A19. LIVING WITH THEIR CHILD/CHILDREN'
   A20     = 'A20. LIVING ARRANGEMENT AT ADMISSION'
   A21     = 'A21. EDUCATION AT ADMISSION'
   A22     = 'A22. STUDENT AT ADMISSION'
   A23     = 'A23. EMPLOYMENT AT ADMISSION'
   A24     = 'A24. USUAL (OR LAST) OCCUPATION'
   A25     = 'A25. DWI/DUI ARRESTS PRIOR TO ADMISSION'
   A26     = 'A26. OTHER ARRESTS PRIOR TO ADMISSION'
   A27     = 'A27. PRISON OR JAIL RECORD PRIOR TO ADMISSION'
   A28     = 'A28. SA TREATMENT AS A CONDITION OF PROBATION/PAROLE'
   A29     = 'A29. NUMBER OF MEDICAL HOSPITALIZATIONS PRIOR TO ADMIT'
   A30A    = 'A30A. AIDS OR HIV SEROPOSITIVE'
   A30B    = 'A30B. STD (OTHER THAN AIDS)'
   A30C    = 'A30C. HEPATITIS OR JAUNDICE'
   A30D    = 'A30D. POSITIVE TB TEST'
   A30E    = 'A30E. ACTIVE TB'
   A30F    = 'A30F. TB, NOT OTHERWISE SPECIFIED'
   A30G    = 'A30G. HEART DISEASE'
   A30H    = 'A30H. HIGH BLOOD PRESSURE'
   A30I    = 'A30I. LIVER DISEASE'
   A30J    = 'A30J.CONVULSIONS'
   A31     = 'A31. HISTORY OF PSYCHOLOGICAL DISORDERS PRIOR TO ADMIT'
   A32     = 'A32. CLIENT TAKING ANTIDEPRESSANT/ANTIPSYCHOTIC AT ADMIT'
   A33A    = 'A33A. DEPRESSION'
   A33B    = 'A33B. SCHIZOPHRENIA'
   A33C    = 'A33C. ANXIETY DISORDER'
   A33D    = 'A33D. PANIC DISORDER'
   A33E    = 'A33E. MANIC DEPRESSIVE ILLNESS, BIPOLAR'
   A33F    = 'A33F. MENTAL DISORDER, NOT OTHERWISE SPECIFIED'
   A34     = 'A34. PRIOR TO ADMIT: TOTAL RESIDENTIAL AND/OR IP MH ADMITS'
   A35     = 'A35. 12 MOS PRIOR: NUMBER OF RESIDENTIAL AND/OR IP MH ADMITS'
   A36     = 'A36. PREGNANCY STATUS AT ADMISSION'
   A37     = 'A37. PREGNANCY STATUS DURING TREATMENT'
   A38     = 'A38. PRESENTING SUBSTANCE ABUSE PROBLEM AT ADMISSION'
   A39CN   = 'A39. ADMISSION: COUNT OF DIAGNOSES'
   A39A    = 'A39A. ADMISSION: PRIMARY DIAGNOSIS'
   A39B    = 'A39B. ADMISSION: OTHER DIAGNOSIS_1'
   A39C    = 'A39C. ADMISSION: OTHER DIAGNOSIS_2'
   A39D    = 'A39D. ADMISSION: OTHER DIAGNOSIS_3'
   A39E    = 'A39E. ADMISSION: OTHER DIAGNOSIS_4'
   A40EU   = 'A40. EVER USED: CRACK'
   A40LU   = 'A40. USED IN LAST 30 DAYS: CRACK'
   A40AGE  = 'A40. AGE AT FIRST USE (IN YEARS): CRACK'
   A41EU   = 'A41. EVER USED: COCAINE'
   A41LU   = 'A41. USED IN LAST 30 DAYS: COCAINE'
   A41AGE  = 'A41. AGE AT FIRST USE (IN YEARS):COCAINE'
   A42EU   = 'A42. EVER USED: HEROIN'
   A42LU   = 'A42. USED IN LAST 30 DAYS: HEROIN'
   A42AGE  = 'A42. AGE AT FIRST USE (IN YEARS): HEROIN'
   A43EU   = 'A43. EVER USED: NON-TRTMT METHADONE'
   A43LU   = 'A43. USED IN LAST 30 DAYS: NON-TRTMT METHADONE'
   A43AGE  = 'A43. AGE AT FIRST USE (IN YEARS): NON-TRTMT METHADONE'
   A44EU   = 'A44. EVER USED: OTHER OPIATES'
   A44LU   = 'A44. USED IN LAST 30 DAYS: OTHER OPIATES'
   A44AGE  = 'A44. AGE AT FIRST USE (IN YEARS): OTHER OPIATES'
   A45EU   = 'A45. EVER USED: BARBITURATES'
   A45LU   = 'A45. USED IN LAST 30 DAYS: BARBITURATES'
   A45AGE  = 'A45. AGE AT FIRST USE (IN YEARS): BARBITURATES'
   A46EU   = 'A46. EVER USED: BENZODIAZEPINES'
   A46LU   = 'A46. USED IN LAST 30 DAYS: BENZODIAZEPINES'
   A46AGE  = 'A46. AGE AT FIRST USE (IN YEARS): BENZODIAZEPINES'
   A47EU   = 'A47. EVER USED: OTHER SEDATIVES/HYPNOTICS'
   A47LU   = 'A47. USED IN LAST 30 DAYS: OTHER SEDATIVES/HYPNOTICS'
   A47AGE  = 'A47. AGE AT FIRST USE (IN YEARS): OTHER SEDATIVES/HYPNOTICS'
   A48EU   = 'A48. EVER USED: AMPHETAMINES'
   A48LU   = 'A48. USED IN LAST 30 DAYS: AMPHETAMINES'
   A48AGE  = 'A48. AGE AT FIRST USE (IN YEARS): AMPHETAMINES'
   A49EU   = 'A49. EVER USED: MARIJUANA/HASHISH/THC'
   A49LU   = 'A49. USED IN LAST 30 DAYS: MARIJUANA/HASHISH/THC'
   A49AGE  = 'A49. AGE AT FIRST USE (IN YEARS): MARIJUANA/HASHISH/THC'
   A50EU   = 'A50. EVER USED: HALLUCINOGENS'
   A50LU   = 'A50. USED IN LAST 30 DAYS: HALLUCINOGENS'
   A50AGE  = 'A50. AGE AT FIRST USE (IN YEARS): HALLUCINOGENS'
   A51EU   = 'A51. EVER USED: INHALANTS'
   A51LU   = 'A51. USED IN LAST 30 DAYS: INHALANTS'
   A51AGE  = 'A51. AGE AT FIRST USE (IN YEARS): INHALANTS'
   A52EU   = 'A52. EVER USED: OVER-THE-COUNTER'
   A52OTH  = 'A52. OVER-THE-COUNTER DRUG SPECIFIED'
   A52LU   = 'A52. USED IN LAST 30 DAYS: OVER-THE-COUNTER'
   A52AGE  = 'A52. AGE AT FIRST USE (IN YEARS): OVER-THE-COUNTER'
   A53EU   = 'A53. EVER USED: ALCOHOL'
   A53LU   = 'A53. USED IN LAST 30 DAYS: ALCOHOL'
   A53AGE  = 'A53. AGE AT FIRST USE (IN YEARS): ALCOHOL'
   A54EU   = 'A54. EVER USED: TOBACCO'
   A54LU   = 'A54. USED IN LAST 30 DAYS: TOBACCO'
   A54AGE  = 'A54. AGE AT FIRST USE (IN YEARS): TOBACCO'
   A55EU   = 'A55. EVER USED: ANY OTHER DRUG_1'
   A55LU   = 'A55. USED IN LAST 30 DAYS: ANY OTHER DRUG_1'
   A55AGE  = 'A55. AGE AT FIRST USE (IN YEARS): ANY OTHER DRUG_1'
   A56EU   = 'A56. EVER USED: ANY OTHER DRUG_2'
   A56LU   = 'A56. USED IN LAST 30 DAYS: ANY OTHER DRUG_2'
   A56AGE  = 'A56. AGE AT FIRST USE (IN YEARS): ANY OTHER DRUG_2'
   A57     = 'A57. SUBSTANCE OF CHOICE SPECIFIED AT ADMISSION'
   A58A    = 'A58A. INJECTION DRUG USER: EVER'
   A58B    = 'A58B. INJECTION DRUG USER: AT ADMISSION'
   A58C    = 'A58C. INJECTION DRUG USER: FREQUENCY AT ADMISSION'
   A59     = 'A59. ANY SUBSTANCE ABUSE TESTING: DURING TREATMENT'
   A60A    = 'A60A. TESTS CONDUCTED: URINE'
   A60B    = 'A60B. TESTS CONDUCTED: SERUM/BLOOD'
   A60C    = 'A60C. TESTS CONDUCTED: OTHER (SPECIFY)'
   A61     = 'A61. FREQUENCY OF SUBSTANCE ABUSE TESTING: DURING TREATMENT'
   A62FOP  = 'A62FOP. FIRST TEST, POSITIVE RESULTS: OPIATES'
   A62FCO  = 'A62FCO. FIRST TEST, POSITIVE RESULTS: COCAINE'
   A62FTHC = 'A62FTHC. FIRST TEST, POSITIVE RESULTS: THC/MARIJUANA'
   A62FOTH = 'A62FOTH. FIRST TEST, POSITIVE RESULTS: OTHER DRUG/ALCOHOL'
   A62LOP  = 'A62LOP. LAST TEST, POSITIVE RESULTS: OPIATES'
   A62LCO  = 'A62LCO. LAST TEST, POSITIVE RESULTS: COCAINE'
   A62LTHC = 'A62LTHC. LAST TEST, POSITIVE RESULTS: THC/MARIJUANA'
   A62LOTH = 'A62LOTH. LAST TEST, POSITIVE RESULTS: OTHER DRUG/ALCOHOL'
   A63     = 'A63. TOTAL NUMBER TREATMENT EPISODES PRIOR TO ADMISSION'
   A64     = 'A64. NUMBER OF YEARS DURING WHICH TREATMENT REPORTED'
   A65     = 'A65. SA TREATMENT EPISODES IN 12 MONTHS PRIOR TO ADMIT'
   A65AR   = 'A65A. REASON: SA TRMT_1 IN 12 MOS PRIOR TO ADMIT'
   A65AF   = 'A65A. FACILITY: SA TRMT_1 IN 12 MOS PRIOR TO ADMIT'
   A65AT   = 'A65A. TYPE OF CARE: SA TRMT_1 IN 12 MOS PRIOR TO ADMIT'
   A65AD   = 'A65A. DISCHARGE STATUS: SA TRMT_1 IN 12 MOS PRIOR TO ADMIT'
   A65BR   = 'A65B. REASON: SA TRMT_2 IN 12 MOS PRIOR TO ADMIT'
   A65BF   = 'A65B. FACILITY: SA TRMT_2 IN 12 MOS PRIOR TO ADMIT'
   A65BT   = 'A65B. TYPE OF CARE: SA TRMT_2 IN 12 MOS PRIOR TO ADMIT'
   A65BD   = 'A65B. DISCHARGE STATUS: SA TRMT_2 IN 12 MOS PRIOR TO ADMIT'
   A65CR   = 'A65C. REASON: SA TRMT_3 IN 12 MOS PRIOR TO ADMIT'
   A65CF   = 'A65C. FACILITY: SA TRMT_3 IN 12 MOS PRIOR TO ADMIT'
   A65CT   = 'A65C. TYPE OF CARE: SA TRMT_3 IN 12 MOS PRIOR TO ADMIT'
   A65CD   = 'A65C. DISCHARGE STATUS: SA TRMT_3 IN 12 MOS PRIOR TO ADMIT'
   A65DR   = 'A65D. REASON: SA TRMT_4 IN 12 MOS PRIOR TO ADMIT'
   A65DF   = 'A65D. FACILITY: SA TRMT_4 IN 12 MOS PRIOR TO ADMIT'
   A65DT   = 'A65D. TYPE OF CARE: SA TRMT_4 IN 12 MOS PRIOR TO ADMIT'
   A65DD   = 'A65D. DISCHARGE STATUS: SA TRMT_4 IN 12 MOS PRIOR TO ADMIT'
   A65ER   = 'A65E. REASON: SA TRMT_5 IN 12 MOS PRIOR TO ADMIT'
   A65EF   = 'A65E. FACILITY: SA TRMT_5 IN 12 MOS PRIOR TO ADMIT'
   A65ET   = 'A65E. TYPE OF CARE: SA TRMT_5 IN 12 MOS PRIOR TO ADMIT'
   A65ED   = 'A65E. DISCHARGE STATUS: SA TRMT_5 IN 12 MOS PRIOR TO ADMIT'
   A65FR   = 'A65F. REASON: SA TRMT_6 IN 12 MOS PRIOR TO ADMIT'
   A65FF   = 'A65F. FACILITY: SA TRMT_6 IN 12 MOS PRIOR TO ADMIT'
   A65FT   = 'A65F. TYPE OF CARE: SA TRMT_6 IN 12 MOS PRIOR TO ADMIT'
   A65FD   = 'A65F. DISCHARGE STATUS: SA TRMT_6 IN 12 MOS PRIOR TO ADMIT'
   A65GR   = 'A65G. REASON: SA TRMT_7 IN 12 MOS PRIOR TO ADMIT'
   A65GF   = 'A65G. FACILITY: SA TRMT_7 IN 12 MOS PRIOR TO ADMIT'
   A65GT   = 'A65G. TYPE OF CARE: SA TRMT_7 IN 12 MOS PRIOR TO ADMIT'
   A65GD   = 'A65G. DISCHARGE STATUS: SA TRMT_7 IN 12 MOS PRIOR TO ADMIT'
   A65HR   = 'A65H. REASON: SA TRMT_8 IN 12 MOS PRIOR TO ADMIT'
   A65HF   = 'A65H. FACILITY: SA TRMT_8 IN 12 MOS PRIOR TO ADMIT'
   A65HT   = 'A65H. TYPE OF CARE: SA TRMT_8 IN 12 MOS PRIOR TO ADMIT'
   A65HD   = 'A65H. DISCHARGE STATUS: SA TRMT_8 IN 12 MOS PRIOR TO ADMIT'
   A65IR   = 'A65I. REASON: SA TRMT_9 IN 12 MOS PRIOR TO ADMIT'
   A65IF   = 'A65I. FACILITY: SA TRMT_9 IN 12 MOS PRIOR TO ADMIT'
   A65IT   = 'A65I. TYPE OF CARE: SA TRMT_9 IN 12 MOS PRIOR TO ADMIT'
   A65ID   = 'A65I. DISCHARGE STATUS: SA TRMT_9 IN 12 MOS PRIOR TO ADMIT'
   A65JR   = 'A65J. REASON: SA TRMT_10 IN 12 MOS PRIOR TO ADMIT'
   A65JF   = 'A65J. FACILITY: SA TRMT_10 IN 12 MOS PRIOR TO ADMIT'
   A65JT   = 'A65J. TYPE OF CARE: SA TRMT_10 IN 12 MOS PRIOR TO ADMIT'
   A65JD   = 'A65J. DISCHARGE STATUS: SA TRMT_10 IN 12 MOS PRIOR TO ADMIT'
   A66     = 'A66. NUMBER OF ACTUAL OUTPATIENT VISITS'
   A67A    = 'A67A. SERVICE GIVEN: METHADONE DOSING'
   A67AN   = 'A67A. NUMBER OF ENCOUNTERS: METHADONE DOSING'
   A67B    = 'A67B. SERVICE GIVEN: INDIVIDUAL THERAPY'
   A67BN   = 'A67B. NUMBER OF ENCOUNTERS: INDIVIDUAL THERAPY'
   A67C    = 'A67C. SERVICE GIVEN: GROUP THERAPY/RELAPSE PREVENTION'
   A67CN   = 'A67C. NUMBER OF ENCOUNTERS: GROUP THERAPY/RELAPSE PREVENTION'
   A67D    = 'A67D. SERVICE GIVEN: FAMILY COUNSELING'
   A67DN   = 'A67D. NUMBER OF ENCOUNTERS: FAMILY COUNSELING'
   A67E    = 'A67E. SERVICE GIVEN: SELF-HELP OR MUTUAL HELP GROUPS'
   A67F    = 'A67F. SERVICE GIVEN: HIV OR AIDS COUNSELING/EDUC/SUPPORT'
   A67G    = 'A67G. SERVICE GIVEN: EMPLOYMENT COUNSELING/TRAINING'
   A67H    = 'A67H. SERVICE GIVEN: ACADEMIC EDUCATION/GED CLASSES'
   A67I    = 'A67I. SERVICE GIVEN: MEDICAL CARE'
   A67J    = 'A67J. SERVICE GIVEN: COMPREHENSIVE ASSESSMENT/DX'
   A67K    = 'A67K. SERVICE GIVEN: DETOXIFICATION FROM SUBSTANCE OF ABUSE'
   A67L    = 'A67L. SERVICE GIVEN: COMBINED SA AND MH TREATMENT'
   A67M    = 'A67M. SERVICE GIVEN: TB SCREENING'
   A67N    = 'A67N. SERVICE GIVEN: TB TREATMENT'
   A67O    = 'A67O. SERVICE GIVEN: PRENATAL CARE'
   A67P    = 'A67P. SERVICE GIVEN: PSYCHOLOGICAL TESTING'
   A67Q    = 'A67Q. SERVICE GIVEN: SMOKING CESSATION'
   A67R    = 'A67R. SERVICE GIVEN: ACUPUNCTURE'
   A67S    = 'A67S. SERVICE GIVEN: OUTCOME FOLLOWUP'
   A67T    = 'A67T. SERVICE GIVEN: AFTERCARE'
   A68     = 'A68. ANY MEDICATIONS PRESCRIBED DURING TRTMT (EXCLUDE METH)'
   A68A1   = 'A68A. FIRST PRESCRIBED MEDICATION'
   A68A2   = 'A68A. SECOND PRESCRIBED MEDICATION'
   A68A3   = 'A68A. THIRD PRESCRIBED MEDICATION'
   A69     = 'A69. METHADONE GIVEN DURING THIS TRTMT EPISODE'
   A69BTD  = 'A69BTD. TOTAL DAILY DOSE IN MGS: TWO WEEKS AFTER FIRST METH'
   A69CTD  = 'A69CTD. TOTAL DAILY DOSE IN MGS: ONE MONTH AFTER FIRST METH'
   A69DTD  = 'A69DTD. TOTAL DAILY DOSE IN MGS: LAST METHADONE TRTMT'
   A70     = 'A70. METHADONE SUPPLY TAKEN HOME DURING THIS TRTMT'
   A73     = 'A73. REASON FOR DISCHARGE'
   A74CN   = 'A74. DISCHARGE: COUNT OF DIAGNOSES'
   A74A    = 'A74A. DISCHARGE: PRIMARY DIAGNOSIS'
   A74B    = 'A74B. DISCHARGE: OTHER DIAGNOSIS_1'
   A74C    = 'A74C. DISCHARGE: OTHER DIAGNOSIS_2'
   A74D    = 'A74D. DISCHARGE: OTHER DIAGNOSIS_3'
   A74E    = 'A74E. DISCHARGE: OTHER DIAGNOSIS_4'
   A75     = 'A75. DUAL DIAGNOSIS: SA/MENTAL ILLNESS AT DISCHARGE'
   A75A    = 'A75A. MENTAL ILLNESS SPECIFIED AT DISCHARGE'
   A76     = 'A76. AFTERCARE PLAN STATED IN RECORD'
   A77     = 'A77. SERVICES IN AFTERCARE PLAN'
   A77A    = 'A77A. AFTERCARE SVCS: INDIVIDUAL THERAPY'
   A77B    = 'A77B. AFTERCARE SVCS: GROUP THERAPY, BUT NOT RELAPSE PREVENT'
   A77C    = 'A77C. AFTERCARE SVCS: RELAPSE PREVENTION GROUPS'
   A77D    = 'A77D. AFTERCARE SVCS: FAMILY COUNSELING'
   A77E    = 'A77E. AFTERCARE SVCS: SELF-HELP OR MUTUAL-HELP GROUPS'
   A77F    = 'A77F. AFTERCARE SVCS: EMPLOYMENT COUNSELING/TRAINING'
   A77G    = 'A77G. AFTERCARES SVCS: LEGAL/CRIMINAL JUSTICE SYSTEM COUNSEL'
   A78     = 'A78. FURTHER SUBSTANCE ABUSE TRTMT REFERRED'
   A79     = 'A79. NUMBER OF AUTHORIZED TREATMENT DAYS/VISITS'
   A79U    = 'A79U. UNIT FOR NUMBER OF TREATMENT DAYS/VISITS'
   A79A    = 'A79A. DAYS/VISITS AUTHORIZED BY'
   A80     = 'A80. TOTAL BILLED CHARGE AMOUNT: FOR THIS TRTMT'
   A80B    = 'A80B. IF NO BILLED CHARGES, WAS TRTMT A CONTRACT SLOT'
   A81     = 'A81. TOTAL BILLED CHARGE TYPE'
   A81PC   = 'A81. TOT BILLED CHARGE PCNT: PERCENT OF TOTAL BILLED CHARGE'
   A82     = 'A82. COMMENTS GIVEN'
   A55OTH  = 'A55. ANY OTHER DRUG_1: FIRST SPECIFIED'
   A56OTH  = 'A56. ANY OTHER DRUG_2: SECOND SPECIFIED'
   AGE_CALC= 'CALCULATED AGE AT ADMISSION'
   LOS     = 'LENGTH OF STAY (DAYS)'
   TRT_DUR = 'TREATMENT DURATION (DAYS)'
   ALCOHOL = 'ALCOHOL CLIENT (1=ALCOHOL USE MENTIONED)'
   DRUG    = 'DRUG CLIENT (1=DRUG MENTIONED)'
   DRUG_ALC= 'ALCOHOL CLIENT, DRUG CLIENT, OR BOTH'
   ABSSMPTY= 'ABSTRACT SAMPLE TYPE'
   QFSTRAT = 'TREATMENT TYPE STRATUM INDICATOR'
   GROUP   = 'INCENTIVE GROUP INDICATOR'
   STUDYIND= 'STUDY INDICATOR'
   FIELDPSU= 'PSU NUMBER'
   PSUTYPE2= 'CENSUS CLASSIFICATION FOR PSUS'
   CENREG  = 'CENSUS REGION'
   OWN     = 'TYPE OF OWNERSHIP'
   FACTYPE = 'PHASE II: FACILITY TREATMENT TYPE'
   TXCARE  = 'CLIENT''STYPE OF TREATMENT'
   VST_PSU = 'PHASE II VARIANCE STRATA'
   VUN_PSU = 'PHASE II VARIANCE UNIT'
   A69ATD  = 'A69ATD. TOTAL DAILY DOSE IN MGS: FIRST TREATMENT'
        ;


* USER-DEFINED MISSING VALUES RECODE TO SAS SYSMIS;

/*
   IF (CASEID <= -1) THEN CASEID = .;
   IF (CLTYPE <= -1) THEN CLTYPE = .;
   IF (COMIN <= -1) THEN COMIN = .;
   IF (A6 <= -1) THEN A6 = .;
   IF (A6A1 <= -1) THEN A6A1 = .;
   IF (A6A2 <= -1) THEN A6A2 = .;
   IF (A6A3 <= -1) THEN A6A3 = .;
   IF (A7 <= -1) THEN A7 = .;
   IF (A9 <= -1) THEN A9 = .;
   IF (A10 <= -1) THEN A10 = .;
   IF (A11 <= -1) THEN A11 = .;
   IF (A14 <= -1) THEN A14 = .;
   IF (A15 <= -1) THEN A15 = .;
   IF (A16 <= -1) THEN A16 = .;
   IF (A17 <= -1) THEN A17 = .;
   IF (A18 <= -1) THEN A18 = .;
   IF (A19 <= -1) THEN A19 = .;
   IF (A20 <= -1) THEN A20 = .;
   IF (A21 <= -1) THEN A21 = .;
   IF (A22 <= -1) THEN A22 = .;
   IF (A23 <= -1) THEN A23 = .;
   IF (A24 <= -1) THEN A24 = .;
   IF (A25 <= -1) THEN A25 = .;
   IF (A26 <= -1) THEN A26 = .;
   IF (A27 <= -1) THEN A27 = .;
   IF (A28 <= -1) THEN A28 = .;
   IF (A29 <= -1) THEN A29 = .;
   IF (A30A <= -1) THEN A30A = .;
   IF (A30B <= -1) THEN A30B = .;
   IF (A30C <= -1) THEN A30C = .;
   IF (A30D <= -1) THEN A30D = .;
   IF (A30E <= -1) THEN A30E = .;
   IF (A30F <= -1) THEN A30F = .;
   IF (A30G <= -1) THEN A30G = .;
   IF (A30H <= -1) THEN A30H = .;
   IF (A30I <= -1) THEN A30I = .;
   IF (A30J <= -1) THEN A30J = .;
   IF (A31 <= -1) THEN A31 = .;
   IF (A32 <= -1) THEN A32 = .;
   IF (A33A <= -1) THEN A33A = .;
   IF (A33B <= -1) THEN A33B = .;
   IF (A33C <= -1) THEN A33C = .;
   IF (A33D <= -1) THEN A33D = .;
   IF (A33E <= -1) THEN A33E = .;
   IF (A33F <= -1) THEN A33F = .;
   IF (A34 <= -1) THEN A34 = .;
   IF (A35 <= -1) THEN A35 = .;
   IF (A36 <= -1) THEN A36 = .;
   IF (A37 <= -1) THEN A37 = .;
   IF (A38 <= -1) THEN A38 = .;
   IF (A39CN <= -1) THEN A39CN = .;
   IF (A39A <= -1) THEN A39A = .;
   IF (A39B <= -1) THEN A39B = .;
   IF (A39C <= -1) THEN A39C = .;
   IF (A39D <= -1) THEN A39D = .;
   IF (A39E <= -1) THEN A39E = .;
   IF (A40EU <= -1) THEN A40EU = .;
   IF (A40LU <= -1) THEN A40LU = .;
   IF (A40AGE <= -1) THEN A40AGE = .;
   IF (A41EU <= -1) THEN A41EU = .;
   IF (A41LU <= -1) THEN A41LU = .;
   IF (A41AGE <= -1) THEN A41AGE = .;
   IF (A42EU <= -1) THEN A42EU = .;
   IF (A42LU <= -1) THEN A42LU = .;
   IF (A42AGE <= -1) THEN A42AGE = .;
   IF (A43EU <= -1) THEN A43EU = .;
   IF (A43LU <= -1) THEN A43LU = .;
   IF (A43AGE <= -1) THEN A43AGE = .;
   IF (A44EU <= -1) THEN A44EU = .;
   IF (A44LU <= -1) THEN A44LU = .;
   IF (A44AGE <= -1) THEN A44AGE = .;
   IF (A45EU <= -1) THEN A45EU = .;
   IF (A45LU <= -1) THEN A45LU = .;
   IF (A45AGE <= -1) THEN A45AGE = .;
   IF (A46EU <= -1) THEN A46EU = .;
   IF (A46LU <= -1) THEN A46LU = .;
   IF (A46AGE <= -1) THEN A46AGE = .;
   IF (A47EU <= -1) THEN A47EU = .;
   IF (A47LU <= -1) THEN A47LU = .;
   IF (A47AGE <= -1) THEN A47AGE = .;
   IF (A48EU <= -1) THEN A48EU = .;
   IF (A48LU <= -1) THEN A48LU = .;
   IF (A48AGE <= -1) THEN A48AGE = .;
   IF (A49EU <= -1) THEN A49EU = .;
   IF (A49LU <= -1) THEN A49LU = .;
   IF (A49AGE <= -1) THEN A49AGE = .;
   IF (A50EU <= -1) THEN A50EU = .;
   IF (A50LU <= -1) THEN A50LU = .;
   IF (A50AGE <= -1) THEN A50AGE = .;
   IF (A51EU <= -1) THEN A51EU = .;
   IF (A51LU <= -1) THEN A51LU = .;
   IF (A51AGE <= -1) THEN A51AGE = .;
   IF (A52EU <= -1) THEN A52EU = .;
   IF (A52OTH <= -1) THEN A52OTH = .;
   IF (A52LU <= -1) THEN A52LU = .;
   IF (A52AGE <= -1) THEN A52AGE = .;
   IF (A53EU <= -1) THEN A53EU = .;
   IF (A53LU <= -1) THEN A53LU = .;
   IF (A53AGE <= -1) THEN A53AGE = .;
   IF (A54EU <= -1) THEN A54EU = .;
   IF (A54LU <= -1) THEN A54LU = .;
   IF (A54AGE <= -1) THEN A54AGE = .;
   IF (A55EU <= -1) THEN A55EU = .;
   IF (A55LU <= -1) THEN A55LU = .;
   IF (A55AGE <= -1) THEN A55AGE = .;
   IF (A56EU <= -1) THEN A56EU = .;
   IF (A56LU <= -1) THEN A56LU = .;
   IF (A56AGE <= -1) THEN A56AGE = .;
   IF (A57 <= -1) THEN A57 = .;
   IF (A58A <= -1) THEN A58A = .;
   IF (A58B <= -1) THEN A58B = .;
   IF (A58C <= -1) THEN A58C = .;
   IF (A59 <= -1) THEN A59 = .;
   IF (A60A <= -1) THEN A60A = .;
   IF (A60B <= -1) THEN A60B = .;
   IF (A60C <= -1) THEN A60C = .;
   IF (A61 <= -1) THEN A61 = .;
   IF (A62FOP <= -1) THEN A62FOP = .;
   IF (A62FCO <= -1) THEN A62FCO = .;
   IF (A62FTHC <= -1) THEN A62FTHC = .;
   IF (A62FOTH <= -1) THEN A62FOTH = .;
   IF (A62LOP <= -1) THEN A62LOP = .;
   IF (A62LCO <= -1) THEN A62LCO = .;
   IF (A62LTHC <= -1) THEN A62LTHC = .;
   IF (A62LOTH <= -1) THEN A62LOTH = .;
   IF (A63 <= -1) THEN A63 = .;
   IF (A64 <= -1) THEN A64 = .;
   IF (A65 <= -1) THEN A65 = .;
   IF (A65AR <= -1) THEN A65AR = .;
   IF (A65AF <= -1) THEN A65AF = .;
   IF (A65AT <= -1) THEN A65AT = .;
   IF (A65AD <= -1) THEN A65AD = .;
   IF (A65BR <= -1) THEN A65BR = .;
   IF (A65BF <= -1) THEN A65BF = .;
   IF (A65BT <= -1) THEN A65BT = .;
   IF (A65BD <= -1) THEN A65BD = .;
   IF (A65CR <= -1) THEN A65CR = .;
   IF (A65CF <= -1) THEN A65CF = .;
   IF (A65CT <= -1) THEN A65CT = .;
   IF (A65CD <= -1) THEN A65CD = .;
   IF (A65DR <= -1) THEN A65DR = .;
   IF (A65DF <= -1) THEN A65DF = .;
   IF (A65DT <= -1) THEN A65DT = .;
   IF (A65DD <= -1) THEN A65DD = .;
   IF (A65ER <= -1) THEN A65ER = .;
   IF (A65EF <= -1) THEN A65EF = .;
   IF (A65ET <= -1) THEN A65ET = .;
   IF (A65ED <= -1) THEN A65ED = .;
   IF (A65FR <= -1) THEN A65FR = .;
   IF (A65FF <= -1) THEN A65FF = .;
   IF (A65FT <= -1) THEN A65FT = .;
   IF (A65FD <= -1) THEN A65FD = .;
   IF (A65GR <= -1) THEN A65GR = .;
   IF (A65GF <= -1) THEN A65GF = .;
   IF (A65GT <= -1) THEN A65GT = .;
   IF (A65GD <= -1) THEN A65GD = .;
   IF (A65HR <= -1) THEN A65HR = .;
   IF (A65HF <= -1) THEN A65HF = .;
   IF (A65HT <= -1) THEN A65HT = .;
   IF (A65HD <= -1) THEN A65HD = .;
   IF (A65IR <= -1) THEN A65IR = .;
   IF (A65IF <= -1) THEN A65IF = .;
   IF (A65IT <= -1) THEN A65IT = .;
   IF (A65ID <= -1) THEN A65ID = .;
   IF (A65JR <= -1) THEN A65JR = .;
   IF (A65JF <= -1) THEN A65JF = .;
   IF (A65JT <= -1) THEN A65JT = .;
   IF (A65JD <= -1) THEN A65JD = .;
   IF (A66 <= -1) THEN A66 = .;
   IF (A67A <= -1) THEN A67A = .;
   IF (A67AN <= -1) THEN A67AN = .;
   IF (A67B <= -1) THEN A67B = .;
   IF (A67BN <= -1) THEN A67BN = .;
   IF (A67C <= -1) THEN A67C = .;
   IF (A67CN <= -1) THEN A67CN = .;
   IF (A67D <= -1) THEN A67D = .;
   IF (A67DN <= -1) THEN A67DN = .;
   IF (A67E <= -1) THEN A67E = .;
   IF (A67F <= -1) THEN A67F = .;
   IF (A67G <= -1) THEN A67G = .;
   IF (A67H <= -1) THEN A67H = .;
   IF (A67I <= -1) THEN A67I = .;
   IF (A67J <= -1) THEN A67J = .;
   IF (A67K <= -1) THEN A67K = .;
   IF (A67L <= -1) THEN A67L = .;
   IF (A67M <= -1) THEN A67M = .;
   IF (A67N <= -1) THEN A67N = .;
   IF (A67O <= -1) THEN A67O = .;
   IF (A67P <= -1) THEN A67P = .;
   IF (A67Q <= -1) THEN A67Q = .;
   IF (A67R <= -1) THEN A67R = .;
   IF (A67S <= -1) THEN A67S = .;
   IF (A67T <= -1) THEN A67T = .;
   IF (A68 <= -1) THEN A68 = .;
   IF (A68A1 <= -1) THEN A68A1 = .;
   IF (A68A2 <= -1) THEN A68A2 = .;
   IF (A68A3 <= -1) THEN A68A3 = .;
   IF (A69 <= -1) THEN A69 = .;
   IF (A69BTD <= -1) THEN A69BTD = .;
   IF (A69CTD <= -1) THEN A69CTD = .;
   IF (A69DTD <= -1) THEN A69DTD = .;
   IF (A70 <= -1) THEN A70 = .;
   IF (A73 <= -1) THEN A73 = .;
   IF (A74CN <= -1) THEN A74CN = .;
   IF (A74A <= -1) THEN A74A = .;
   IF (A74B <= -1) THEN A74B = .;
   IF (A74C <= -1) THEN A74C = .;
   IF (A74D <= -1) THEN A74D = .;
   IF (A74E <= -1) THEN A74E = .;
   IF (A75 <= -1) THEN A75 = .;
   IF (A75A <= -1) THEN A75A = .;
   IF (A76 <= -1) THEN A76 = .;
   IF (A77 <= -1) THEN A77 = .;
   IF (A77A <= -1) THEN A77A = .;
   IF (A77B <= -1) THEN A77B = .;
   IF (A77C <= -1) THEN A77C = .;
   IF (A77D <= -1) THEN A77D = .;
   IF (A77E <= -1) THEN A77E = .;
   IF (A77F <= -1) THEN A77F = .;
   IF (A77G <= -1) THEN A77G = .;
   IF (A78 <= -1) THEN A78 = .;
   IF (A79 <= -1) THEN A79 = .;
   IF (A79U <= -1) THEN A79U = .;
   IF (A79A <= -1) THEN A79A = .;
   IF (A80 <= -1) THEN A80 = .;
   IF (A80B <= -1) THEN A80B = .;
   IF (A81 <= -1) THEN A81 = .;
   IF (A81PC <= -1) THEN A81PC = .;
   IF (A82 <= -1) THEN A82 = .;
   IF (A55OTH <= -1) THEN A55OTH = .;
   IF (A56OTH <= -1) THEN A56OTH = .;
   IF (AGE_CALC <= -1) THEN AGE_CALC = .;
   IF (LOS <= -1) THEN LOS = .;
   IF (TRT_DUR <= -1) THEN TRT_DUR = .;
   IF (ALCOHOL <= -1) THEN ALCOHOL = .;
   IF (DRUG <= -1) THEN DRUG = .;
   IF (DRUG_ALC <= -1) THEN DRUG_ALC = .;
   IF (ABSSMPTY <= -1) THEN ABSSMPTY = .;
   IF (QFSTRAT <= -1) THEN QFSTRAT = .;
   IF (GROUP <= -1) THEN GROUP = .;
   IF (STUDYIND <= -1) THEN STUDYIND = .;
   IF (FIELDPSU <= -1) THEN FIELDPSU = .;
   IF (PSUTYPE2 <= -1) THEN PSUTYPE2 = .;
   IF (CENREG <= -1) THEN CENREG = .;
   IF (OWN <= -1) THEN OWN = .;
   IF (FACTYPE <= -1) THEN FACTYPE = .;
   IF (TXCARE <= -1) THEN TXCARE = .;
   IF (VST_PSU <= -1) THEN VST_PSU = .;
   IF (VUN_PSU <= -1) THEN VUN_PSU = .;
   IF (A69ATD <= -1) THEN A69ATD = .;
*/


* SAS FORMAT STATEMENT;

/*
  FORMAT CLTYPE cltype. COMIN comin. A6 a6ffffff.
         A6A1 a6a1ffff. A6A2 a6a2ffff. A6A3 a6a3ffff.
         A7 a7ffffff. A9 a9ffffff. A10 a10fffff.
         A11 a11fffff. A14 a14fffff. A15 a15fffff.
         A16 a16fffff. A17 a17fffff. A18 a18fffff.
         A19 a19fffff. A20 a20fffff. A21 a21fffff.
         A22 a22fffff. A23 a23fffff. A24 a24fffff.
         A25 a25fffff. A26 a26fffff. A27 a27fffff.
         A28 a28fffff. A29 a29fffff. A30A a30a.
         A30B a30b. A30C a30c. A30D a30d.
         A30E a30e. A30F a30f. A30G a30g.
         A30H a30h. A30I a30i. A30J a30j.
         A31 a31fffff. A32 a32fffff. A33A a33a.
         A33B a33b. A33C a33c. A33D a33d.
         A33E a33e. A33F a33f. A34 a34fffff.
         A35 a35fffff. A36 a36fffff. A37 a37fffff.
         A38 a38fffff. A39CN a39cn. A39A a39a.
         A39B a39b. A39C a39c. A39D a39d.
         A39E a39e. A40EU a40eu. A40LU a40lu.
         A40AGE a40age. A41EU a41eu. A41LU a41lu.
         A41AGE a41age. A42EU a42eu. A42LU a42lu.
         A42AGE a42age. A43EU a43eu. A43LU a43lu.
         A43AGE a43age. A44EU a44eu. A44LU a44lu.
         A44AGE a44age. A45EU a45eu. A45LU a45lu.
         A45AGE a45age. A46EU a46eu. A46LU a46lu.
         A46AGE a46age. A47EU a47eu. A47LU a47lu.
         A47AGE a47age. A48EU a48eu. A48LU a48lu.
         A48AGE a48age. A49EU a49eu. A49LU a49lu.
         A49AGE a49age. A50EU a50eu. A50LU a50lu.
         A50AGE a50age. A51EU a51eu. A51LU a51lu.
         A51AGE a51age. A52EU a52eu. A52OTH a52oth.
         A52LU a52lu. A52AGE a52age. A53EU a53eu.
         A53LU a53lu. A53AGE a53age. A54EU a54eu.
         A54LU a54lu. A54AGE a54age. A55EU a55eu.
         A55LU a55lu. A55AGE a55age. A56EU a56eu.
         A56LU a56lu. A56AGE a56age. A57 a57fffff.
         A58A a58a. A58B a58b. A58C a58c.
         A59 a59fffff. A60A a60a. A60B a60b.
         A60C a60c. A61 a61fffff. A62FOP a62fop.
         A62FCO a62fco. A62FTHC a62fthc. A62FOTH a62foth.
         A62LOP a62lop. A62LCO a62lco. A62LTHC a62lthc.
         A62LOTH a62loth. A63 a63fffff. A64 a64fffff.
         A65 a65fffff. A65AR a65ar. A65AF a65af.
         A65AT a65at. A65AD a65ad. A65BR a65br.
         A65BF a65bf. A65BT a65bt. A65BD a65bd.
         A65CR a65cr. A65CF a65cf. A65CT a65ct.
         A65CD a65cd. A65DR a65dr. A65DF a65df.
         A65DT a65dt. A65DD a65dd. A65ER a65er.
         A65EF a65ef. A65ET a65et. A65ED a65ed.
         A65FR a65fr. A65FF a65ff. A65FT a65ft.
         A65FD a65fd. A65GR a65gr. A65GF a65gf.
         A65GT a65gt. A65GD a65gd. A65HR a65hr.
         A65HF a65hf. A65HT a65ht. A65HD a65hd.
         A65IR a65ir. A65IF a65if. A65IT a65it.
         A65ID a65id. A65JR a65jr. A65JF a65jf.
         A65JT a65jt. A65JD a65jd. A66 a66fffff.
         A67A a67a. A67AN a67an. A67B a67b.
         A67BN a67bn. A67C a67c. A67CN a67cn.
         A67D a67d. A67DN a67dn. A67E a67e.
         A67F a67f. A67G a67g. A67H a67h.
         A67I a67i. A67J a67j. A67K a67k.
         A67L a67l. A67M a67m. A67N a67n.
         A67O a67o. A67P a67p. A67Q a67q.
         A67R a67r. A67S a67s. A67T a67t.
         A68 a68fffff. A68A1 a68a1fff. A68A2 a68a2fff.
         A68A3 a68a3fff. A69 a69fffff. A69BTD a69btd.
         A69CTD a69ctd. A69DTD a69dtd. A70 a70fffff.
         A73 a73fffff. A74CN a74cn. A74A a74a.
         A74B a74b. A74C a74c. A74D a74d.
         A74E a74e. A75 a75fffff. A75A a75a.
         A76 a76fffff. A77 a77fffff. A77A a77a.
         A77B a77b. A77C a77c. A77D a77d.
         A77E a77e. A77F a77f. A77G a77g.
         A78 a78fffff. A79 a79fffff. A79U a79u.
         A79A a79a. A80 a80fffff. A80B a80b.
         A81 a81fffff. A81PC a81pc. A82 a82fffff.
         A55OTH a55oth. A56OTH a56oth. AGE_CALC age_calc.
         LOS los. TRT_DUR trt_dur. ALCOHOL alcohol.
         DRUG drug. DRUG_ALC drug_alc. ABSSMPTY abssmpty.
         QFSTRAT qfstrat. GROUP group. STUDYIND studyind.
         PSUTYPE2 psutypef. CENREG cenreg. OWN own.
         FACTYPE factype. TXCARE txcare. A69ATD a69atd.
          ;
*/

RUN ;
